{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "ATAC-seq 01 QC - reads: SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Adapters file",
                    "type": "File",
                    "id": "#01-qc-se.cwl/default_adapters_file"
                },
                {
                    "doc": "Input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#01-qc-se.cwl/input_fastq_files"
                },
                {
                    "doc": "Number of threads.",
                    "type": "int",
                    "id": "#01-qc-se.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#diff.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-qc-se.cwl/compare_read_counts/file1",
                        "#01-qc-se.cwl/compare_read_counts/file2"
                    ],
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/count_raw_reads/output_read_count",
                            "id": "#01-qc-se.cwl/compare_read_counts/file1"
                        },
                        {
                            "source": "#01-qc-se.cwl/count_fastqc_reads/output_fastqc_read_count",
                            "id": "#01-qc-se.cwl/compare_read_counts/file2"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/compare_read_counts/result"
                    ],
                    "id": "#01-qc-se.cwl/compare_read_counts"
                },
                {
                    "run": "#count-fastqc-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-qc-se.cwl/count_fastqc_reads/input_fastqc_data",
                        "#01-qc-se.cwl/count_fastqc_reads/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/extract_basename/basename",
                            "id": "#01-qc-se.cwl/count_fastqc_reads/input_basename"
                        },
                        {
                            "source": "#01-qc-se.cwl/extract_fastqc_data/output_fastqc_data_file",
                            "id": "#01-qc-se.cwl/count_fastqc_reads/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/count_fastqc_reads/output_fastqc_read_count"
                    ],
                    "id": "#01-qc-se.cwl/count_fastqc_reads"
                },
                {
                    "run": "#count-fastq-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-qc-se.cwl/count_raw_reads/input_fastq_file",
                        "#01-qc-se.cwl/count_raw_reads/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/extract_basename/basename",
                            "id": "#01-qc-se.cwl/count_raw_reads/input_basename"
                        },
                        {
                            "source": "#01-qc-se.cwl/input_fastq_files",
                            "id": "#01-qc-se.cwl/count_raw_reads/input_fastq_file"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/count_raw_reads/output_read_count"
                    ],
                    "id": "#01-qc-se.cwl/count_raw_reads"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#01-qc-se.cwl/extract_basename/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#01-qc-se.cwl/extract_basename/do_not_escape_sep"
                        },
                        {
                            "source": "#01-qc-se.cwl/input_fastq_files",
                            "valueFrom": "$(self.basename)",
                            "id": "#01-qc-se.cwl/extract_basename/file_path"
                        },
                        {
                            "valueFrom": "(\\.fastq.gz|\\.fastq)",
                            "id": "#01-qc-se.cwl/extract_basename/sep"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/extract_basename/basename"
                    ],
                    "id": "#01-qc-se.cwl/extract_basename"
                },
                {
                    "run": "#extract_fastqc_data.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-qc-se.cwl/extract_fastqc_data/input_qc_report_file",
                        "#01-qc-se.cwl/extract_fastqc_data/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/extract_basename/basename",
                            "id": "#01-qc-se.cwl/extract_fastqc_data/input_basename"
                        },
                        {
                            "source": "#01-qc-se.cwl/fastqc/output_qc_report_file",
                            "id": "#01-qc-se.cwl/extract_fastqc_data/input_qc_report_file"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/extract_fastqc_data/output_fastqc_data_file"
                    ],
                    "id": "#01-qc-se.cwl/extract_fastqc_data"
                },
                {
                    "run": "#fastqc.cwl",
                    "scatter": "#01-qc-se.cwl/fastqc/input_fastq_file",
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/input_fastq_files",
                            "id": "#01-qc-se.cwl/fastqc/input_fastq_file"
                        },
                        {
                            "source": "#01-qc-se.cwl/nthreads",
                            "id": "#01-qc-se.cwl/fastqc/threads"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/fastqc/output_qc_report_file"
                    ],
                    "id": "#01-qc-se.cwl/fastqc"
                },
                {
                    "run": "#overrepresented_sequence_extract.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#01-qc-se.cwl/overrepresented_sequence_extract/input_fastqc_data",
                        "#01-qc-se.cwl/overrepresented_sequence_extract/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#01-qc-se.cwl/default_adapters_file",
                            "id": "#01-qc-se.cwl/overrepresented_sequence_extract/default_adapters_file"
                        },
                        {
                            "source": "#01-qc-se.cwl/extract_basename/basename",
                            "id": "#01-qc-se.cwl/overrepresented_sequence_extract/input_basename"
                        },
                        {
                            "source": "#01-qc-se.cwl/extract_fastqc_data/output_fastqc_data_file",
                            "id": "#01-qc-se.cwl/overrepresented_sequence_extract/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#01-qc-se.cwl/overrepresented_sequence_extract/output_custom_adapters"
                    ],
                    "id": "#01-qc-se.cwl/overrepresented_sequence_extract"
                }
            ],
            "id": "#01-qc-se.cwl",
            "outputs": [
                {
                    "outputSource": "#01-qc-se.cwl/count_raw_reads/output_read_count",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#01-qc-se.cwl/output_count_raw_reads"
                },
                {
                    "outputSource": "#01-qc-se.cwl/overrepresented_sequence_extract/output_custom_adapters",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#01-qc-se.cwl/output_custom_adapters"
                },
                {
                    "outputSource": "#01-qc-se.cwl/compare_read_counts/result",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#01-qc-se.cwl/output_diff_counts"
                },
                {
                    "doc": "FastQC data files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-qc-se.cwl/extract_fastqc_data/output_fastqc_data_file",
                    "id": "#01-qc-se.cwl/output_fastqc_data_files"
                },
                {
                    "doc": "FastQC reports in zip format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#01-qc-se.cwl/fastqc/output_qc_report_file",
                    "id": "#01-qc-se.cwl/output_fastqc_report_files"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "ATAC-seq 02 trimming - reads: SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Input adapters files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#02-trim-se.cwl/input_adapters_files"
                },
                {
                    "doc": "Input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#02-trim-se.cwl/input_fastq_files"
                },
                {
                    "default": 1,
                    "doc": "Number of threads",
                    "type": "int",
                    "id": "#02-trim-se.cwl/nthreads"
                },
                {
                    "default": "-phred33",
                    "type": "string",
                    "id": "#02-trim-se.cwl/quality_score"
                },
                {
                    "default": "/usr/share/java/trimmomatic.jar",
                    "doc": "Trimmomatic Java jar file",
                    "type": "string",
                    "id": "#02-trim-se.cwl/trimmomatic_jar_path"
                },
                {
                    "doc": "JVM arguments should be a quoted, space separated list",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#02-trim-se.cwl/trimmomatic_java_opts"
                }
            ],
            "steps": [
                {
                    "run": "#count-fastq-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#02-trim-se.cwl/count_fastq_reads/input_fastq_file",
                        "#02-trim-se.cwl/count_fastq_reads/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#02-trim-se.cwl/extract_basename/basename",
                            "id": "#02-trim-se.cwl/count_fastq_reads/input_basename"
                        },
                        {
                            "source": "#02-trim-se.cwl/trimmomatic/output_read1_trimmed_file",
                            "id": "#02-trim-se.cwl/count_fastq_reads/input_fastq_file"
                        }
                    ],
                    "out": [
                        "#02-trim-se.cwl/count_fastq_reads/output_read_count"
                    ],
                    "id": "#02-trim-se.cwl/count_fastq_reads"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#02-trim-se.cwl/extract_basename/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#02-trim-se.cwl/extract_basename/do_not_escape_sep"
                        },
                        {
                            "source": "#02-trim-se.cwl/trimmomatic/output_read1_trimmed_file",
                            "valueFrom": "$(self.basename)",
                            "id": "#02-trim-se.cwl/extract_basename/file_path"
                        },
                        {
                            "valueFrom": "(\\.fastq.gz|\\.fastq)",
                            "id": "#02-trim-se.cwl/extract_basename/sep"
                        }
                    ],
                    "out": [
                        "#02-trim-se.cwl/extract_basename/basename"
                    ],
                    "id": "#02-trim-se.cwl/extract_basename"
                },
                {
                    "run": "#trimmomatic.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#02-trim-se.cwl/trimmomatic/input_read1_fastq_file",
                        "#02-trim-se.cwl/trimmomatic/input_adapters_file"
                    ],
                    "in": [
                        {
                            "valueFrom": "SE",
                            "id": "#02-trim-se.cwl/trimmomatic/end_mode"
                        },
                        {
                            "valueFrom": "2:30:15",
                            "id": "#02-trim-se.cwl/trimmomatic/illuminaclip"
                        },
                        {
                            "source": "#02-trim-se.cwl/input_adapters_files",
                            "id": "#02-trim-se.cwl/trimmomatic/input_adapters_file"
                        },
                        {
                            "source": "#02-trim-se.cwl/input_fastq_files",
                            "id": "#02-trim-se.cwl/trimmomatic/input_read1_fastq_file"
                        },
                        {
                            "source": "#02-trim-se.cwl/trimmomatic_java_opts",
                            "id": "#02-trim-se.cwl/trimmomatic/java_opts"
                        },
                        {
                            "valueFrom": "${return 3}",
                            "id": "#02-trim-se.cwl/trimmomatic/leading"
                        },
                        {
                            "valueFrom": "${return 15}",
                            "id": "#02-trim-se.cwl/trimmomatic/minlen"
                        },
                        {
                            "source": "#02-trim-se.cwl/nthreads",
                            "id": "#02-trim-se.cwl/trimmomatic/nthreads"
                        },
                        {
                            "valueFrom": "33",
                            "id": "#02-trim-se.cwl/trimmomatic/phred"
                        },
                        {
                            "valueFrom": "4:20",
                            "id": "#02-trim-se.cwl/trimmomatic/slidingwindow"
                        },
                        {
                            "valueFrom": "${return 3}",
                            "id": "#02-trim-se.cwl/trimmomatic/trailing"
                        },
                        {
                            "source": "#02-trim-se.cwl/trimmomatic_jar_path",
                            "id": "#02-trim-se.cwl/trimmomatic/trimmomatic_jar_path"
                        }
                    ],
                    "out": [
                        "#02-trim-se.cwl/trimmomatic/output_read1_trimmed_file"
                    ],
                    "id": "#02-trim-se.cwl/trimmomatic"
                }
            ],
            "outputs": [
                {
                    "doc": "Trimmed fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-trim-se.cwl/trimmomatic/output_read1_trimmed_file",
                    "id": "#02-trim-se.cwl/output_data_fastq_trimmed_files"
                },
                {
                    "doc": "Trimmed read counts of fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#02-trim-se.cwl/count_fastq_reads/output_read_count",
                    "id": "#02-trim-se.cwl/output_trimmed_fastq_read_count"
                }
            ],
            "id": "#02-trim-se.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ATAC-seq 03 mapping - reads: SE - blacklist removal",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#03-map-se-blacklist-removal.cwl/ENCODE_blacklist_bedfile"
                },
                {
                    "doc": "Bowtie first index files for reference genome (e.g. *1.ebwt). The rest of the files should be in the same folder.",
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.ebwt",
                        "^^.3.ebwt",
                        "^^.4.ebwt",
                        "^^.rev.1.ebwt",
                        "^^.rev.2.ebwt"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/genome_ref_first_index_file"
                },
                {
                    "doc": "Genome sizes tab-delimited file (used in samtools)",
                    "type": "File",
                    "id": "#03-map-se-blacklist-removal.cwl/genome_sizes_file"
                },
                {
                    "doc": "Input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#03-map-se-blacklist-removal.cwl/input_fastq_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#03-map-se-blacklist-removal.cwl/nthreads"
                },
                {
                    "default": "/usr/picard/picard.jar",
                    "doc": "Picard Java jar file",
                    "type": "string",
                    "id": "#03-map-se-blacklist-removal.cwl/picard_jar_path"
                },
                {
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/picard_java_opts"
                }
            ],
            "steps": [
                {
                    "run": "#samtools-idxstats.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/bam_idxstats/bam",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/index_bams/indexed_file",
                            "id": "#03-map-se-blacklist-removal.cwl/bam_idxstats/bam"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/bam_idxstats/idxstats_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/bam_idxstats"
                },
                {
                    "run": "#bowtie-se.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/bowtie-se/input_fastq_file",
                        "#03-map-se-blacklist-removal.cwl/bowtie-se/output_filename"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return 2000}",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/X"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/genome_ref_first_index_file",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/genome_ref_first_index_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/input_fastq_files",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/input_fastq_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/nthreads"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/output_filename"
                        },
                        {
                            "valueFrom": "${return 2}",
                            "id": "#03-map-se-blacklist-removal.cwl/bowtie-se/v"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/bowtie-se/output_aligned_file",
                        "#03-map-se-blacklist-removal.cwl/bowtie-se/output_bowtie_log"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/bowtie-se"
                },
                {
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/genome_sizes_file",
                            "id": "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef/genome_sizes"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/filtered2sorted/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef/input_bam_files"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename",
                            "id": "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef/input_output_filenames"
                        }
                    ],
                    "run": "#pcr-bottleneck-coef.cwl",
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef/pbc_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef"
                },
                {
                    "run": "#basename.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/extract_basename_1/file_path",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#03-map-se-blacklist-removal.cwl/extract_basename_1/do_not_escape_sep"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/input_fastq_files",
                            "valueFrom": "$(self.basename)",
                            "id": "#03-map-se-blacklist-removal.cwl/extract_basename_1/file_path"
                        },
                        {
                            "valueFrom": "(\\.fastq.gz|\\.fastq)",
                            "id": "#03-map-se-blacklist-removal.cwl/extract_basename_1/sep"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/extract_basename_1"
                },
                {
                    "run": "#samtools-filter-unmapped.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/filter-unmapped/input_file",
                        "#03-map-se-blacklist-removal.cwl/filter-unmapped/output_filename"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/filter-unmapped/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename",
                            "id": "#03-map-se-blacklist-removal.cwl/filter-unmapped/output_filename"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/filter-unmapped/filtered_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/filter-unmapped"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/filter-unmapped/filtered_file",
                            "id": "#03-map-se-blacklist-removal.cwl/filtered2sorted/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/filtered2sorted/nthreads"
                        }
                    ],
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/filtered2sorted/input_file"
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/filtered2sorted/sorted_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/filtered2sorted"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/index_bams/input_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/index_bams/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/index_bams/indexed_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/index_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/index_dedup_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/index_dedup_bams/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/index_dedup_bams/indexed_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/index_dedup_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams/indexed_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/index_filtered_bam/input_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/filtered2sorted/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/index_filtered_bam/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/index_filtered_bam/indexed_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/index_filtered_bam"
                },
                {
                    "run": "#samtools-index.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/index_masked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_masked_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/index_masked_bams/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/index_masked_bams/indexed_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/index_masked_bams"
                },
                {
                    "run": "#samtools-extract-number-mapped-reads.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count/input_bam_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count/input_bam_file"
                        },
                        {
                            "valueFrom": ".mapped_and_filtered.read_count.txt",
                            "id": "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count/output_suffix"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count/output_read_count"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count"
                },
                {
                    "run": "#bowtie-log-read-count.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/mapped_reads_count/bowtie_log",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/bowtie-se/output_bowtie_log",
                            "id": "#03-map-se-blacklist-removal.cwl/mapped_reads_count/bowtie_log"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/mapped_reads_count/output"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/mapped_reads_count"
                },
                {
                    "run": "#picard-MarkDuplicates.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/mark_duplicates/input_file",
                        "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_filename"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/index_masked_bams/indexed_file",
                            "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/picard_java_opts",
                            "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates/java_opts"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/masked_file_basename/output_basename",
                            "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_filename"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_suffix"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/picard_jar_path",
                            "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates/picard_jar_path"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_metrics_file",
                        "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_dedup_bam_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/mark_duplicates"
                },
                {
                    "run": "#extract-basename.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/masked_file_basename/input_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/file_wo_blacklist_regions",
                            "id": "#03-map-se-blacklist-removal.cwl/masked_file_basename/input_file"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/masked_file_basename/output_basename"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/masked_file_basename"
                },
                {
                    "run": "#idxstats-percentage-of-reads-in-chrom.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/idxstats",
                    "in": [
                        {
                            "valueFrom": "chrM",
                            "id": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/chrom"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/bam_idxstats/idxstats_file",
                            "id": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/idxstats"
                        },
                        {
                            "valueFrom": "${return inputs.idxstats.basename.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '').replace(/\\.[^/.]+$/, '').replace(/\\.[^/.]+$/, '.mitochondrial_percentage.txt')}",
                            "id": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/output_filename"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/percent_map"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads"
                },
                {
                    "run": "#preseq-percent-uniq-reads.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/percent_uniq_reads/preseq_c_curve_outfile",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/preseq-c-curve/output_file",
                            "id": "#03-map-se-blacklist-removal.cwl/percent_uniq_reads/preseq_c_curve_outfile"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/percent_uniq_reads/output"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/percent_uniq_reads"
                },
                {
                    "run": "#preseq-c_curve.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/preseq-c-curve/input_sorted_file",
                        "#03-map-se-blacklist-removal.cwl/preseq-c-curve/output_file_basename"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/filtered2sorted/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/preseq-c-curve/input_sorted_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename",
                            "id": "#03-map-se-blacklist-removal.cwl/preseq-c-curve/output_file_basename"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/preseq-c-curve/output_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/preseq-c-curve"
                },
                {
                    "run": "#samtools-view.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/remove_duplicates/input_file"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return 1024}",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates/F"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates/b"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams/indexed_file",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates/input_file"
                        },
                        {
                            "valueFrom": "${return inputs.input_file.basename.replace('dups_marked', 'dedup')}",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates/outfile_name"
                        },
                        {
                            "valueFrom": ".dedup.bam",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates/suffix"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/remove_duplicates/outfile"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/remove_duplicates"
                },
                {
                    "run": "#bedtools-intersect.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/a",
                        "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/output_basename_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/filtered2sorted/sorted_file",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/a"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/ENCODE_blacklist_bedfile",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/b"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/extract_basename_1/basename",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/output_basename_file"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/v"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/file_wo_blacklist_regions"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist"
                },
                {
                    "run": "#samtools2bam.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/sam2bam/input_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/bowtie-se/output_aligned_file",
                            "id": "#03-map-se-blacklist-removal.cwl/sam2bam/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/sam2bam/nthreads"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/sam2bam/bam_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/sam2bam"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": "#03-map-se-blacklist-removal.cwl/sort_bams/input_file",
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/sam2bam/bam_file",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_bams/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/sort_bams/sorted_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/sort_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/remove_duplicates/outfile",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/sort_dedup_bams/sorted_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/sort_dedup_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_dedup_bam_file",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/nthreads"
                        },
                        {
                            "valueFrom": ".dups_marked.bam",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/suffix"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams/sorted_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/sort_dups_marked_bams"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": [
                        "#03-map-se-blacklist-removal.cwl/sort_masked_bams/input_file"
                    ],
                    "in": [
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/remove_encode_blacklist/file_wo_blacklist_regions",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_masked_bams/input_file"
                        },
                        {
                            "source": "#03-map-se-blacklist-removal.cwl/nthreads",
                            "id": "#03-map-se-blacklist-removal.cwl/sort_masked_bams/nthreads"
                        }
                    ],
                    "out": [
                        "#03-map-se-blacklist-removal.cwl/sort_masked_bams/sorted_file"
                    ],
                    "id": "#03-map-se-blacklist-removal.cwl/sort_masked_bams"
                }
            ],
            "outputs": [
                {
                    "doc": "Bowtie log file.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/bowtie-se/output_bowtie_log",
                    "id": "#03-map-se-blacklist-removal.cwl/output_bowtie_log"
                },
                {
                    "doc": "BAM files without duplicate reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/index_dedup_bams/indexed_file",
                    "id": "#03-map-se-blacklist-removal.cwl/output_data_sorted_dedup_bam_files"
                },
                {
                    "doc": "BAM files with marked duplicate reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/index_dups_marked_bams/indexed_file",
                    "id": "#03-map-se-blacklist-removal.cwl/output_data_sorted_dups_marked_bam_files"
                },
                {
                    "doc": "PCR Bottleneck Coeficient files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/execute_pcr_bottleneck_coef/pbc_file",
                    "id": "#03-map-se-blacklist-removal.cwl/output_pbc_files"
                },
                {
                    "doc": "Percentage of mitochondrial reads.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/percent_mitochondrial_reads/percent_map",
                    "id": "#03-map-se-blacklist-removal.cwl/output_percent_mitochondrial_reads"
                },
                {
                    "doc": "Percentage of uniq reads from preseq c_curve output",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/percent_uniq_reads/output",
                    "id": "#03-map-se-blacklist-removal.cwl/output_percentage_uniq_reads"
                },
                {
                    "doc": "Picard MarkDuplicates metrics files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/mark_duplicates/output_metrics_file",
                    "id": "#03-map-se-blacklist-removal.cwl/output_picard_mark_duplicates_files"
                },
                {
                    "doc": "Preseq c_curve output files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/preseq-c-curve/output_file",
                    "id": "#03-map-se-blacklist-removal.cwl/output_preseq_c_curve_files"
                },
                {
                    "doc": "Read counts of the mapped BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/mapped_reads_count/output",
                    "id": "#03-map-se-blacklist-removal.cwl/output_read_count_mapped"
                },
                {
                    "doc": "Read counts of the mapped and filtered BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#03-map-se-blacklist-removal.cwl/mapped_filtered_reads_count/output_read_count",
                    "id": "#03-map-se-blacklist-removal.cwl/output_read_count_mapped_filtered"
                }
            ],
            "id": "#03-map-se-blacklist-removal.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ATAC-seq 04 quantification - SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Definition narrowPeak file in AutoSql format (used in bedToBigBed)",
                    "type": "File",
                    "id": "#04-peakcall-se.cwl/as_narrowPeak_file"
                },
                {
                    "default": "hs",
                    "doc": "Effective genome size used by MACS2. It can be numeric or a shortcuts:'hs' for human (2.7e9), 'mm' for mouse (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for fruitfly (1.2e8), Default:hs",
                    "type": "string",
                    "id": "#04-peakcall-se.cwl/genome_effective_size"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#04-peakcall-se.cwl/input_bam_files"
                },
                {
                    "doc": "Two column tab-delimited file with chromosome size information",
                    "type": "File",
                    "id": "#04-peakcall-se.cwl/input_genome_sizes"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#04-peakcall-se.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#count-with-output-suffix.cwl",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/peak-calling/output_peak_file",
                            "id": "#04-peakcall-se.cwl/count-peaks/input_file"
                        },
                        {
                            "valueFrom": ".peak_count.within_replicate.txt",
                            "id": "#04-peakcall-se.cwl/count-peaks/output_suffix"
                        }
                    ],
                    "scatter": "#04-peakcall-se.cwl/count-peaks/input_file",
                    "out": [
                        "#04-peakcall-se.cwl/count-peaks/output_counts"
                    ],
                    "id": "#04-peakcall-se.cwl/count-peaks"
                },
                {
                    "run": "#count-reads-after-filtering.cwl",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/peak-calling/output_peak_xls_file",
                            "id": "#04-peakcall-se.cwl/count-reads-filtered/peak_xls_file"
                        }
                    ],
                    "scatter": "#04-peakcall-se.cwl/count-reads-filtered/peak_xls_file",
                    "out": [
                        "#04-peakcall-se.cwl/count-reads-filtered/read_count_file"
                    ],
                    "id": "#04-peakcall-se.cwl/count-reads-filtered"
                },
                {
                    "run": "#samtools-extract-number-mapped-reads.cwl",
                    "scatter": "#04-peakcall-se.cwl/extract-count-reads-in-peaks/input_bam_file",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/filter-reads-in-peaks/filtered_file",
                            "id": "#04-peakcall-se.cwl/extract-count-reads-in-peaks/input_bam_file"
                        },
                        {
                            "valueFrom": ".read_count.within_replicate.txt",
                            "id": "#04-peakcall-se.cwl/extract-count-reads-in-peaks/output_suffix"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/extract-count-reads-in-peaks/output_read_count"
                    ],
                    "id": "#04-peakcall-se.cwl/extract-count-reads-in-peaks"
                },
                {
                    "run": "#extract-best-frag-length.cwl",
                    "scatter": "#04-peakcall-se.cwl/extract-peak-frag-length/input_spp_txt_file",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/spp/output_spp_cross_corr",
                            "id": "#04-peakcall-se.cwl/extract-peak-frag-length/input_spp_txt_file"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/extract-peak-frag-length/output_best_frag_length"
                    ],
                    "id": "#04-peakcall-se.cwl/extract-peak-frag-length"
                },
                {
                    "run": "#samtools-filter-in-bedfile.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#04-peakcall-se.cwl/filter-reads-in-peaks/input_bam_file",
                        "#04-peakcall-se.cwl/filter-reads-in-peaks/input_bedfile"
                    ],
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/input_bam_files",
                            "id": "#04-peakcall-se.cwl/filter-reads-in-peaks/input_bam_file"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/peak-calling/output_peak_file",
                            "id": "#04-peakcall-se.cwl/filter-reads-in-peaks/input_bedfile"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/filter-reads-in-peaks/filtered_file"
                    ],
                    "id": "#04-peakcall-se.cwl/filter-reads-in-peaks"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#04-peakcall-se.cwl/peak-calling/treatment"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#04-peakcall-se.cwl/peak-calling/bdg"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#04-peakcall-se.cwl/peak-calling/extsize"
                        },
                        {
                            "valueFrom": "BAM",
                            "id": "#04-peakcall-se.cwl/peak-calling/format"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/genome_effective_size",
                            "id": "#04-peakcall-se.cwl/peak-calling/g"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#04-peakcall-se.cwl/peak-calling/nomodel"
                        },
                        {
                            "valueFrom": "${return 0.1}",
                            "id": "#04-peakcall-se.cwl/peak-calling/q"
                        },
                        {
                            "valueFrom": "${return -100}",
                            "id": "#04-peakcall-se.cwl/peak-calling/shift"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/input_bam_files",
                            "valueFrom": "$([self])",
                            "id": "#04-peakcall-se.cwl/peak-calling/treatment"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/peak-calling/output_peak_file",
                        "#04-peakcall-se.cwl/peak-calling/output_peak_summits_file",
                        "#04-peakcall-se.cwl/peak-calling/output_ext_frag_bdg_file",
                        "#04-peakcall-se.cwl/peak-calling/output_peak_xls_file"
                    ],
                    "id": "#04-peakcall-se.cwl/peak-calling"
                },
                {
                    "run": "#bedToBigBed.cwl",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/as_narrowPeak_file",
                            "id": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/as"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/trunk-peak-score/trunked_scores_peaks",
                            "id": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/bed"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/input_genome_sizes",
                            "id": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/genome_sizes"
                        },
                        {
                            "valueFrom": "bed6+4",
                            "id": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/type"
                        }
                    ],
                    "scatter": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/bed",
                    "out": [
                        "#04-peakcall-se.cwl/peaks-bed-to-bigbed/bigbed"
                    ],
                    "id": "#04-peakcall-se.cwl/peaks-bed-to-bigbed"
                },
                {
                    "run": "#spp.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#04-peakcall-se.cwl/spp/input_bam"
                    ],
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/input_bam_files",
                            "id": "#04-peakcall-se.cwl/spp/input_bam"
                        },
                        {
                            "source": "#04-peakcall-se.cwl/nthreads",
                            "id": "#04-peakcall-se.cwl/spp/nthreads"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#04-peakcall-se.cwl/spp/savp"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/spp/output_spp_cross_corr",
                        "#04-peakcall-se.cwl/spp/output_spp_cross_corr_plot"
                    ],
                    "id": "#04-peakcall-se.cwl/spp"
                },
                {
                    "run": "#trunk-peak-score.cwl",
                    "scatter": "#04-peakcall-se.cwl/trunk-peak-score/peaks",
                    "in": [
                        {
                            "source": "#04-peakcall-se.cwl/peak-calling/output_peak_file",
                            "id": "#04-peakcall-se.cwl/trunk-peak-score/peaks"
                        }
                    ],
                    "out": [
                        "#04-peakcall-se.cwl/trunk-peak-score/trunked_scores_peaks"
                    ],
                    "id": "#04-peakcall-se.cwl/trunk-peak-score"
                }
            ],
            "outputs": [
                {
                    "doc": "peakshift/phantomPeak extended fragment results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/peak-calling/output_ext_frag_bdg_file",
                    "id": "#04-peakcall-se.cwl/output_extended_peak_file"
                },
                {
                    "doc": "Filtered read count reported by MACS2",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/count-reads-filtered/read_count_file",
                    "id": "#04-peakcall-se.cwl/output_filtered_read_count_file"
                },
                {
                    "doc": "Peaks in bigBed format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/peaks-bed-to-bigbed/bigbed",
                    "id": "#04-peakcall-se.cwl/output_peak_bigbed_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/count-peaks/output_counts",
                    "id": "#04-peakcall-se.cwl/output_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/peak-calling/output_peak_file",
                    "id": "#04-peakcall-se.cwl/output_peak_file"
                },
                {
                    "doc": "File containing peak summits",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/peak-calling/output_peak_summits_file",
                    "id": "#04-peakcall-se.cwl/output_peak_summits_file"
                },
                {
                    "doc": "Peak calling report file (*_peaks.xls file produced by MACS2)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/peak-calling/output_peak_xls_file",
                    "id": "#04-peakcall-se.cwl/output_peak_xls_file"
                },
                {
                    "doc": "Reads peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/extract-count-reads-in-peaks/output_read_count",
                    "id": "#04-peakcall-se.cwl/output_read_in_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/spp/output_spp_cross_corr_plot",
                    "id": "#04-peakcall-se.cwl/output_spp_cross_corr_plot"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#04-peakcall-se.cwl/spp/output_spp_cross_corr",
                    "id": "#04-peakcall-se.cwl/output_spp_x_cross_corr"
                }
            ],
            "id": "#04-peakcall-se.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ATAC-seq - Quantification",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#05-quantification.cwl/input_bam_files"
                },
                {
                    "type": "File",
                    "id": "#05-quantification.cwl/input_genome_sizes"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#05-quantification.cwl/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "scatter": "#05-quantification.cwl/bamcoverage/bam",
                    "in": [
                        {
                            "source": "#05-quantification.cwl/input_bam_files",
                            "id": "#05-quantification.cwl/bamcoverage/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#05-quantification.cwl/bamcoverage/binSize"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#05-quantification.cwl/bamcoverage/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#05-quantification.cwl/bamcoverage/normalizeUsing"
                        },
                        {
                            "source": "#05-quantification.cwl/nthreads",
                            "id": "#05-quantification.cwl/bamcoverage/numberOfProcessors"
                        },
                        {
                            "valueFrom": ".rpkm.bw",
                            "id": "#05-quantification.cwl/bamcoverage/output_suffix"
                        }
                    ],
                    "out": [
                        "#05-quantification.cwl/bamcoverage/output_bam_coverage"
                    ],
                    "id": "#05-quantification.cwl/bamcoverage"
                },
                {
                    "run": "#bedGraphToBigWig.cwl",
                    "scatter": "#05-quantification.cwl/bdg2bw-raw/bed_graph",
                    "in": [
                        {
                            "source": "#05-quantification.cwl/bedsort_genomecov/bed_file_sorted",
                            "id": "#05-quantification.cwl/bdg2bw-raw/bed_graph"
                        },
                        {
                            "source": "#05-quantification.cwl/input_genome_sizes",
                            "id": "#05-quantification.cwl/bdg2bw-raw/genome_sizes"
                        },
                        {
                            "valueFrom": ".raw.bw",
                            "id": "#05-quantification.cwl/bdg2bw-raw/output_suffix"
                        }
                    ],
                    "out": [
                        "#05-quantification.cwl/bdg2bw-raw/output_bigwig"
                    ],
                    "id": "#05-quantification.cwl/bdg2bw-raw"
                },
                {
                    "run": "#bedSort.cwl",
                    "scatter": "#05-quantification.cwl/bedsort_genomecov/bed_file",
                    "in": [
                        {
                            "source": "#05-quantification.cwl/bedtools_genomecov/output_bedfile",
                            "id": "#05-quantification.cwl/bedsort_genomecov/bed_file"
                        }
                    ],
                    "out": [
                        "#05-quantification.cwl/bedsort_genomecov/bed_file_sorted"
                    ],
                    "id": "#05-quantification.cwl/bedsort_genomecov"
                },
                {
                    "run": "#bedtools-genomecov.cwl",
                    "scatter": "#05-quantification.cwl/bedtools_genomecov/ibam",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#05-quantification.cwl/bedtools_genomecov/bg"
                        },
                        {
                            "source": "#05-quantification.cwl/input_genome_sizes",
                            "id": "#05-quantification.cwl/bedtools_genomecov/g"
                        },
                        {
                            "source": "#05-quantification.cwl/input_bam_files",
                            "id": "#05-quantification.cwl/bedtools_genomecov/ibam"
                        }
                    ],
                    "out": [
                        "#05-quantification.cwl/bedtools_genomecov/output_bedfile"
                    ],
                    "id": "#05-quantification.cwl/bedtools_genomecov"
                }
            ],
            "outputs": [
                {
                    "doc": "signal files of pileup reads in RPKM",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#05-quantification.cwl/bamcoverage/output_bam_coverage",
                    "id": "#05-quantification.cwl/bigwig_norm_files"
                },
                {
                    "doc": "Raw reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#05-quantification.cwl/bdg2bw-raw/output_bigwig",
                    "id": "#05-quantification.cwl/bigwig_raw_files"
                }
            ],
            "id": "#05-quantification.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ATAC-seq pipeline - reads: SE - with blacklist removal",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#main/ENCODE_blacklist_bedfile"
                },
                {
                    "doc": "Definition narrowPeak file in AutoSql format (used in bedToBigBed)",
                    "type": "File",
                    "id": "#main/as_narrowPeak_file"
                },
                {
                    "doc": "Adapters file",
                    "type": "File",
                    "id": "#main/default_adapters_file"
                },
                {
                    "default": "hs",
                    "doc": "Effective genome size used by MACS2. It can be numeric or a shortcuts:'hs' for human (2.7e9), 'mm' for mouse (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for fruitfly (1.2e8), Default:hs",
                    "type": "string",
                    "id": "#main/genome_effective_size"
                },
                {
                    "doc": "\"First index file of Bowtie reference genome with extension 1.ebwt. \\ (Note: the rest of the index files MUST be in the same folder)\" ",
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.ebwt",
                        "^^.3.ebwt",
                        "^^.4.ebwt",
                        "^^.rev.1.ebwt",
                        "^^.rev.2.ebwt"
                    ],
                    "id": "#main/genome_ref_first_index_file"
                },
                {
                    "doc": "Genome sizes tab-delimited file (used in samtools)",
                    "type": "File",
                    "id": "#main/genome_sizes_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_fastq_files"
                },
                {
                    "doc": "Number of threads required for the 03-map step",
                    "type": "int",
                    "id": "#main/nthreads_map"
                },
                {
                    "doc": "Number of threads required for the 04-peakcall step",
                    "type": "int",
                    "id": "#main/nthreads_peakcall"
                },
                {
                    "doc": "Number of threads required for the 01-qc step",
                    "type": "int",
                    "id": "#main/nthreads_qc"
                },
                {
                    "doc": "Number of threads required for the 05-quantification step",
                    "type": "int",
                    "id": "#main/nthreads_quant"
                },
                {
                    "doc": "Number of threads required for the 02-trim step",
                    "type": "int",
                    "id": "#main/nthreads_trimm"
                },
                {
                    "doc": "Picard Java jar file",
                    "type": "string",
                    "id": "#main/picard_jar_path"
                },
                {
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/picard_java_opts"
                },
                {
                    "doc": "Trimmomatic Java jar file",
                    "type": "string",
                    "id": "#main/trimmomatic_jar_path"
                },
                {
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/trimmomatic_java_opts"
                }
            ],
            "steps": [
                {
                    "run": "#03-map-se-blacklist-removal.cwl",
                    "in": [
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/map/ENCODE_blacklist_bedfile"
                        },
                        {
                            "source": "#main/genome_ref_first_index_file",
                            "id": "#main/map/genome_ref_first_index_file"
                        },
                        {
                            "source": "#main/genome_sizes_file",
                            "id": "#main/map/genome_sizes_file"
                        },
                        {
                            "source": "#main/trimm/output_data_fastq_trimmed_files",
                            "id": "#main/map/input_fastq_files"
                        },
                        {
                            "source": "#main/nthreads_map",
                            "id": "#main/map/nthreads"
                        },
                        {
                            "source": "#main/picard_jar_path",
                            "id": "#main/map/picard_jar_path"
                        },
                        {
                            "source": "#main/picard_java_opts",
                            "id": "#main/map/picard_java_opts"
                        }
                    ],
                    "out": [
                        "#main/map/output_data_sorted_dedup_bam_files",
                        "#main/map/output_data_sorted_dups_marked_bam_files",
                        "#main/map/output_picard_mark_duplicates_files",
                        "#main/map/output_pbc_files",
                        "#main/map/output_bowtie_log",
                        "#main/map/output_preseq_c_curve_files",
                        "#main/map/output_percentage_uniq_reads",
                        "#main/map/output_read_count_mapped",
                        "#main/map/output_percent_mitochondrial_reads"
                    ],
                    "id": "#main/map"
                },
                {
                    "run": "#04-peakcall-se.cwl",
                    "in": [
                        {
                            "source": "#main/as_narrowPeak_file",
                            "id": "#main/peak_call/as_narrowPeak_file"
                        },
                        {
                            "source": "#main/genome_effective_size",
                            "id": "#main/peak_call/genome_effective_size"
                        },
                        {
                            "source": "#main/map/output_data_sorted_dedup_bam_files",
                            "id": "#main/peak_call/input_bam_files"
                        },
                        {
                            "valueFrom": "BAM",
                            "id": "#main/peak_call/input_bam_format"
                        },
                        {
                            "source": "#main/genome_sizes_file",
                            "id": "#main/peak_call/input_genome_sizes"
                        },
                        {
                            "source": "#main/nthreads_peakcall",
                            "id": "#main/peak_call/nthreads"
                        }
                    ],
                    "out": [
                        "#main/peak_call/output_spp_x_cross_corr",
                        "#main/peak_call/output_spp_cross_corr_plot",
                        "#main/peak_call/output_read_in_peak_count_within_replicate",
                        "#main/peak_call/output_peak_file",
                        "#main/peak_call/output_peak_bigbed_file",
                        "#main/peak_call/output_peak_summits_file",
                        "#main/peak_call/output_extended_peak_file",
                        "#main/peak_call/output_peak_xls_file",
                        "#main/peak_call/output_filtered_read_count_file",
                        "#main/peak_call/output_peak_count_within_replicate"
                    ],
                    "id": "#main/peak_call"
                },
                {
                    "run": "#01-qc-se.cwl",
                    "in": [
                        {
                            "source": "#main/default_adapters_file",
                            "id": "#main/qc/default_adapters_file"
                        },
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/qc/input_fastq_files"
                        },
                        {
                            "source": "#main/nthreads_qc",
                            "id": "#main/qc/nthreads"
                        }
                    ],
                    "out": [
                        "#main/qc/output_count_raw_reads",
                        "#main/qc/output_diff_counts",
                        "#main/qc/output_fastqc_report_files",
                        "#main/qc/output_fastqc_data_files",
                        "#main/qc/output_custom_adapters"
                    ],
                    "id": "#main/qc"
                },
                {
                    "run": "#05-quantification.cwl",
                    "in": [
                        {
                            "source": "#main/map/output_data_sorted_dedup_bam_files",
                            "id": "#main/quant/input_bam_files"
                        },
                        {
                            "source": "#main/genome_sizes_file",
                            "id": "#main/quant/input_genome_sizes"
                        },
                        {
                            "source": "#main/nthreads_quant",
                            "id": "#main/quant/nthreads"
                        }
                    ],
                    "out": [
                        "#main/quant/bigwig_raw_files",
                        "#main/quant/bigwig_norm_files"
                    ],
                    "id": "#main/quant"
                },
                {
                    "run": "#02-trim-se.cwl",
                    "in": [
                        {
                            "source": "#main/qc/output_custom_adapters",
                            "id": "#main/trimm/input_adapters_files"
                        },
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/trimm/input_fastq_files"
                        },
                        {
                            "source": "#main/nthreads_trimm",
                            "id": "#main/trimm/nthreads"
                        },
                        {
                            "source": "#main/trimmomatic_jar_path",
                            "id": "#main/trimm/trimmomatic_jar_path"
                        },
                        {
                            "source": "#main/trimmomatic_java_opts",
                            "id": "#main/trimm/trimmomatic_java_opts"
                        }
                    ],
                    "out": [
                        "#main/trimm/output_data_fastq_trimmed_files",
                        "#main/trimm/output_trimmed_fastq_read_count"
                    ],
                    "id": "#main/trimm"
                }
            ],
            "outputs": [
                {
                    "doc": "Bowtie log file with mapping stats",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_bowtie_log",
                    "id": "#main/map_bowtie_log_files"
                },
                {
                    "doc": "Filtered BAM files (post-processing end point)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_data_sorted_dups_marked_bam_files",
                    "id": "#main/map_dedup_bam_files"
                },
                {
                    "doc": "Summary of duplicates removed with Picard tool MarkDuplicates (for multiple reads aligned to the same positions",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_picard_mark_duplicates_files",
                    "id": "#main/map_mark_duplicates_files"
                },
                {
                    "doc": "PCR Bottleneck Coefficient files (used to flag samples when pbc<0.5)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_pbc_files",
                    "id": "#main/map_pbc_files"
                },
                {
                    "doc": "Percentage of mitochondrial reads",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_percent_mitochondrial_reads",
                    "id": "#main/map_percent_mitochondrial_reads"
                },
                {
                    "doc": "Preseq c_curve output files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_preseq_c_curve_files",
                    "id": "#main/map_preseq_c_curve_files"
                },
                {
                    "doc": "Preseq percentage of uniq reads",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_percentage_uniq_reads",
                    "id": "#main/map_preseq_percentage_uniq_reads"
                },
                {
                    "doc": "Read counts of the mapped BAM files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/map/output_read_count_mapped",
                    "id": "#main/map_read_count_mapped"
                },
                {
                    "doc": "Extended fragment peaks in ENCODE Peak file format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_extended_peak_file",
                    "id": "#main/peakcall_extended_peak_file"
                },
                {
                    "doc": "Filtered read count after peak calling",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_filtered_read_count_file",
                    "id": "#main/peakcall_filtered_read_count_file"
                },
                {
                    "doc": "Peaks in bigBed format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_bigbed_file",
                    "id": "#main/peakcall_peak_bigbed_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_count_within_replicate",
                    "id": "#main/peakcall_peak_count_within_replicate"
                },
                {
                    "doc": "Peaks in ENCODE Peak file format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_file",
                    "id": "#main/peakcall_peak_file"
                },
                {
                    "doc": "Peaks summits in bedfile format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_summits_file",
                    "id": "#main/peakcall_peak_summits_file"
                },
                {
                    "doc": "Peak calling report file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_peak_xls_file",
                    "id": "#main/peakcall_peak_xls_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_read_in_peak_count_within_replicate",
                    "id": "#main/peakcall_read_in_peak_count_within_replicate"
                },
                {
                    "doc": "SPP strand cross correlation summary",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_spp_x_cross_corr",
                    "id": "#main/peakcall_spp_x_cross_corr"
                },
                {
                    "doc": "SPP strand cross correlation plot",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak_call/output_spp_cross_corr_plot",
                    "id": "#main/peakcall_spp_x_cross_corr_plot"
                },
                {
                    "doc": "Raw read counts of fastq files after QC",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/output_count_raw_reads",
                    "id": "#main/qc_count_raw_reads"
                },
                {
                    "doc": "Diff file between number of raw reads and number of reads counted by FASTQC,",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/output_diff_counts",
                    "id": "#main/qc_diff_counts"
                },
                {
                    "doc": "FastQC data files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/output_fastqc_data_files",
                    "id": "#main/qc_fastqc_data_files"
                },
                {
                    "doc": "FastQC reports in zip format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/output_fastqc_report_files",
                    "id": "#main/qc_fastqc_report_files"
                },
                {
                    "doc": "Normalized reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_norm_files",
                    "id": "#main/quant_bigwig_norm_files"
                },
                {
                    "doc": "Raw reads bigWig (signal) files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/quant/bigwig_raw_files",
                    "id": "#main/quant_bigwig_raw_files"
                },
                {
                    "doc": "FASTQ files  after trimming",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/trimm/output_data_fastq_trimmed_files",
                    "id": "#main/trimm_fastq_files"
                },
                {
                    "doc": "Raw read counts of fastq files after trimming",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/trimm/output_trimmed_fastq_read_count",
                    "id": "#main/trimm_raw_counts"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools genomecov (aka genomeCoverageBed)\nVersion: v2.25.0\nSummary: Compute the coverage of a feature file among a genome.\n\nUsage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions: \n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero \n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0 \n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations \n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6). \n\t\t\t- (STRING): can be + or -\n\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes: \n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips: \n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-3"
                    },
                    "doc": "\tCalculate coverage of 3\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-5"
                    },
                    "doc": "\tCalculate coverage of 5\" positions (instead of entire interval).\n",
                    "id": "#bedtools-genomecov.cwl/5"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bg"
                    },
                    "doc": "\tReport depth in BedGraph format. For details, see:\ngenome.ucsc.edu/goldenPath/help/bedgraph.html\n",
                    "id": "#bedtools-genomecov.cwl/bg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bga"
                    },
                    "doc": "\tReport depth in BedGraph format, as above (-bg).\nHowever with this option, regions with zero\ncoverage are also reported. This allows one to\nquickly extract all regions of a genome with 0\ncoverage by applying: \"grep -w 0$\" to the output.\n",
                    "id": "#bedtools-genomecov.cwl/bga"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "doc": "\tReport the depth at each genome position (with one-based coordinates).\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/d"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-dz"
                    },
                    "doc": "\tReport the depth at each genome position (with zero-based coordinates).\nReports only non-zero positions.\nDefault behavior is to report a histogram.\n",
                    "id": "#bedtools-genomecov.cwl/dz"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-g"
                    },
                    "doc": "<genome sizes>",
                    "id": "#bedtools-genomecov.cwl/g"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-ibam"
                    },
                    "doc": "\tThe input file is in BAM format.\nNote: BAM _must_ be sorted by position\n",
                    "id": "#bedtools-genomecov.cwl/ibam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-max"
                    },
                    "doc": "\tCombine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-scale"
                    },
                    "doc": "\tScale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-strand"
                    },
                    "doc": "\tCalculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackline"
                    },
                    "doc": "Adds a UCSC/Genome-Browser track line definition in the first line of the output.\n- See here for more details about track line definition:\nhttp://genome.ucsc.edu/goldenPath/help/bedgraph.html\n- NOTE: When adding a trackline definition, the output BedGraph can be easily\nuploaded to the Genome Browser as a custom track,\nBUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n",
                    "id": "#bedtools-genomecov.cwl/trackline"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-trackopts"
                    },
                    "doc": "Writes additional track line definition parameters in the first line.\n- Example:\n-trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\nNote the use of single-quotes if you have spaces in your parameters.\n- (TEXT)\n",
                    "id": "#bedtools-genomecov.cwl/trackopts"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')"
                    },
                    "id": "#bedtools-genomecov.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "stdout": "$(inputs.ibam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bdg')",
            "id": "#bedtools-genomecov.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:    bedtools intersect (aka intersectBed)\nVersion: v2.25.0\nSummary: Report overlaps between two feature files.\n\nUsage:   bedtools intersect [OPTIONS] -a <bed/gff/vcf/bam> -b <bed/gff/vcf/bam>\n\n\tNote: -b may be followed with multiple databases and/or \n\twildcard (*) character(s). \nOptions: \n\t-wa\tWrite the original entry in A for each overlap.\n\n\t-wb\tWrite the original entry in B for each overlap.\n\t\t- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n\n\t-loj\tPerform a \"left outer join\". That is, for each feature in A\n\t\treport each overlap with B.  If no overlaps are found, \n\t\treport a NULL feature for B.\n\n\t-wo\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlaps restricted by -f and -r.\n\t\t  Only A features with overlap are reported.\n\n\t-wao\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlapping features restricted by -f and -r.\n\t\t  However, A features w/o overlap are also reported\n\t\t  with a NULL B feature and overlap = 0.\n\n\t-u\tWrite the original A entry _once_ if _any_ overlaps found in B.\n\t\t- In other words, just report the fact >=1 hit was found.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-c\tFor each entry in A, report the number of overlaps with B.\n\t\t- Reports 0 for A entries that have no overlap with B.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-v\tOnly report those entries in A that have _no overlaps_ with B.\n\t\t- Similar to \"grep -v\" (an homage).\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n\t-s\tRequire same strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _same_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-S\tRequire different strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _opposite_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-f\tMinimum overlap required as a fraction of A.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-F\tMinimum overlap required as a fraction of B.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-r\tRequire that the fraction overlap be reciprocal for A AND B.\n\t\t- In other words, if -f is 0.90 and -r is used, this requires\n\t\t  that B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n\n\t-e\tRequire that the minimum fraction be satisfied for A OR B.\n\t\t- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\n\t\t  that either 90 percent of A is covered OR 10 percent of  B is covered.\n\t\t  Without -e, both fractions would have to be satisfied.\n\n\t-split\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\n\t-g\tProvide a genome file to enforce consistent chromosome sort order\n\t\tacross input files. Only applies when used with -sorted option.\n\n\t-nonamecheck\tFor sorted data, don't throw an error if the file has different naming conventions\n\t\t\tfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n\n\t-sorted\tUse the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n\n\t-names\tWhen using multiple databases, provide an alias for each that\n\t\twill appear instead of a fileId when also printing the DB record.\n\n\t-filenames\tWhen using multiple databases, show each complete filename\n\t\t\tinstead of a fileId when also printing the DB record.\n\n\t-sortout\tWhen using multiple databases, sort the output DB hits\n\t\t\tfor each record.\n\n\t-bed\tIf using BAM input, write output as BED.\n\n\t-header\tPrint the header from the A file prior to results.\n\n\t-nobuf\tDisable buffered output. Using this option will cause each line\n\t\tof output to be printed as it is generated, rather than saved\n\t\tin a buffer. This will make printing large output files \n\t\tnoticeably slower, but can be useful in conjunction with\n\t\tother software tools and scripts that need to process one\n\t\tline of bedtools output at a time.\n\n\t-iobuf\tSpecify amount of memory to use for input buffer.\n\t\tTakes an integer argument. Optional suffixes K/M/G supported.\n\t\tNote: currently has no effect with compressed files.\n\nNotes: \n\t(1) When a BAM file is used for the A file, the alignment is retained if overlaps exist,\n\tand exlcuded if an overlap cannot be found.  If multiple overlaps exist, they are not\n\treported, as we are only testing for one or more overlaps.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "Minimum overlap required as a fraction of B.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "id": "#bedtools-intersect.cwl/F"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Require different strandedness.  That is, only report hits in B\nthat overlap A on the _opposite_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "id": "#bedtools-intersect.cwl/S"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "Input <bed/gff/vcf/bam> file",
                    "id": "#bedtools-intersect.cwl/a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-b"
                    },
                    "doc": "<bed/gff/vcf/bam>",
                    "id": "#bedtools-intersect.cwl/b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed"
                    },
                    "doc": "If using BAM input, write output as BED.\n",
                    "id": "#bedtools-intersect.cwl/bed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "For each entry in A, report the number of overlaps with B.\n- Reports 0 for A entries that have no overlap with B.\n- Overlaps restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    },
                    "doc": "Require that the minimum fraction be satisfied for A OR B.\n- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\nthat either 90 percent of A is covered OR 10 percent of  B is covered.\nWithout -e, both fractions would have to be satisfied.\n",
                    "id": "#bedtools-intersect.cwl/e"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "Minimum overlap required as a fraction of A.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "id": "#bedtools-intersect.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-filenames"
                    },
                    "doc": "When using multiple databases, show each complete filename\ninstead of a fileId when also printing the DB record.\n",
                    "id": "#bedtools-intersect.cwl/filenames"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "Provide a genome file to enforce consistent chromosome sort order\nacross input files. Only applies when used with -sorted option.\n",
                    "id": "#bedtools-intersect.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-header"
                    },
                    "doc": "Print the header from the A file prior to results.\n",
                    "id": "#bedtools-intersect.cwl/header"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-iobuf"
                    },
                    "doc": "Specify amount of memory to use for input buffer.\nTakes an integer argument. Optional suffixes K/M/G supported.\nNote: currently has no effect with compressed files.\n",
                    "id": "#bedtools-intersect.cwl/iobuf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-loj"
                    },
                    "doc": "Perform a \"left outer join\". That is, for each feature in A\nreport each overlap with B.  If no overlaps are found,\nreport a NULL feature for B.\n",
                    "id": "#bedtools-intersect.cwl/loj"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-names"
                    },
                    "doc": "When using multiple databases, provide an alias for each that\nwill appear instead of a fileId when also printing the DB record.\n",
                    "id": "#bedtools-intersect.cwl/names"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nobuf"
                    },
                    "doc": "Disable buffered output. Using this option will cause each line\nof output to be printed as it is generated, rather than saved\nin a buffer. This will make printing large output files\nnoticeably slower, but can be useful in conjunction with\nother software tools and scripts that need to process one\nline of bedtools output at a time.\n",
                    "id": "#bedtools-intersect.cwl/nobuf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nonamecheck"
                    },
                    "doc": "For sorted data, don't throw an error if the file has different naming conventions\nfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n",
                    "id": "#bedtools-intersect.cwl/nonamecheck"
                },
                {
                    "type": "string",
                    "id": "#bedtools-intersect.cwl/output_basename_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "Require that the fraction overlap be reciprocal for A AND B.\n- In other words, if -f is 0.90 and -r is used, this requires\nthat B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n",
                    "id": "#bedtools-intersect.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "Require same strandedness.  That is, only report hits in B\nthat overlap A on the _same_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "id": "#bedtools-intersect.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sorted"
                    },
                    "doc": "Use the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n",
                    "id": "#bedtools-intersect.cwl/sorted"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sortout"
                    },
                    "doc": "When using multiple databases, sort the output DB hits\nfor each record.\n",
                    "id": "#bedtools-intersect.cwl/sortout"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Treat \"split\" BAM or BED12 entries as distinct BED intervals.\n",
                    "id": "#bedtools-intersect.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "Write the original A entry _once_ if _any_ overlaps found in B.\n- In other words, just report the fact >=1 hit was found.\n- Overlaps restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/u"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    },
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "id": "#bedtools-intersect.cwl/ubam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "Only report those entries in A that have _no overlaps_ with B.\n- Similar to \"grep -v\" (an homage).\n",
                    "id": "#bedtools-intersect.cwl/v"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wa"
                    },
                    "doc": "Write the original entry in A for each overlap.\n",
                    "id": "#bedtools-intersect.cwl/wa"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wao"
                    },
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlapping features restricted by -f and -r.\nHowever, A features w/o overlap are also reported\nwith a NULL B feature and overlap = 0.\n",
                    "id": "#bedtools-intersect.cwl/wao"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wb"
                    },
                    "doc": "Write the original entry in B for each overlap.\n- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n",
                    "id": "#bedtools-intersect.cwl/wb"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wo"
                    },
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlaps restricted by -f and -r.\nOnly A features with overlap are reported.\n",
                    "id": "#bedtools-intersect.cwl/wo"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_basename_file + '.masked.bam')"
                    },
                    "id": "#bedtools-intersect.cwl/file_wo_blacklist_regions"
                }
            ],
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "stdout": "$(inputs.output_basename_file + '.masked.bam')",
            "id": "#bedtools-intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get number of processed reads from Bowtie log.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {},
                    "id": "#bowtie-log-read-count.cwl/bowtie_log"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bowtie_log.path.replace(/^.*[\\\\\\/]/, '') + '.read_count.mapped')"
                    },
                    "id": "#bowtie-log-read-count.cwl/output"
                }
            ],
            "baseCommand": "read-count-from-bowtie-log.sh",
            "stdout": "$(inputs.bowtie_log.path.replace(/^.*[\\\\\\/]/, '') + '.read_count.mapped')",
            "id": "#bowtie-log-read-count.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/bowtie:1.2.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-X"
                    },
                    "doc": "maximum insert size for paired-end alignment (default: 250)",
                    "id": "#bowtie-se.cwl/X"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--best"
                    },
                    "doc": "Hits guaranteed best stratum; ties broken by quality",
                    "id": "#bowtie-se.cwl/best"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--chunkmbs"
                    },
                    "doc": "The number of megabytes of memory a given thread is given to store path descriptors in --best mode. (Default: 256)",
                    "id": "#bowtie-se.cwl/chunkmbs"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^^.2.ebwt",
                        "^^.3.ebwt",
                        "^^.4.ebwt",
                        "^^.rev.1.ebwt",
                        "^^.rev.2.ebwt"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "valueFrom": "$(self.path.split('.').splice(0,self.path.split('.').length-2).join(\".\"))"
                    },
                    "doc": "First file (extension .1.ebwt) of the Bowtie index files generated for the reference genome (see http://bowtie-bio.sourceforge.net/tutorial.shtml#newi)",
                    "id": "#bowtie-se.cwl/genome_ref_first_index_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "doc": "Query input FASTQ file.",
                    "id": "#bowtie-se.cwl/input_fastq_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-m"
                    },
                    "doc": "Suppress all alignments if > <int> exist (def: 1)",
                    "id": "#bowtie-se.cwl/m"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--threads"
                    },
                    "doc": "<int> number of alignment threads to launch (default: 1)",
                    "id": "#bowtie-se.cwl/nthreads"
                },
                {
                    "type": "string",
                    "id": "#bowtie-se.cwl/output_filename"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--sam"
                    },
                    "doc": "Write hits in SAM format (default: BAM)",
                    "id": "#bowtie-se.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedlen"
                    },
                    "doc": "seed length for -n (default: 28)",
                    "id": "#bowtie-se.cwl/seedlen"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seedmms"
                    },
                    "doc": "max mismatches in seed (between [0, 3], default: 2)",
                    "id": "#bowtie-se.cwl/seedmms"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--strata"
                    },
                    "doc": "Hits in sub-optimal strata aren't reported (requires --best)",
                    "id": "#bowtie-se.cwl/strata"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "Print wall-clock time taken by search phases",
                    "id": "#bowtie-se.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim3"
                    },
                    "doc": "trim <int> bases from 3' (right) end of reads",
                    "id": "#bowtie-se.cwl/trim3"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trim5"
                    },
                    "doc": "trim <int> bases from 5' (left) end of reads",
                    "id": "#bowtie-se.cwl/trim5"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-v"
                    },
                    "doc": "Report end-to-end hits w/ <=v mismatches; ignore qualities",
                    "id": "#bowtie-se.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.sam')"
                    },
                    "doc": "Aligned bowtie file in [SAM|BAM] format.",
                    "id": "#bowtie-se.cwl/output_aligned_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.bowtie.log')"
                    },
                    "id": "#bowtie-se.cwl/output_bowtie_log"
                }
            ],
            "baseCommand": "bowtie",
            "stderr": "$(inputs.output_filename + '.bowtie.log')",
            "arguments": [
                {
                    "valueFrom": "$(inputs.output_filename + '.sam')",
                    "position": 11
                }
            ],
            "id": "#bowtie-se.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compute PCR Bottleneck Coeficient from BedGraph file.",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#compute-pbc.cwl/bedgraph_file"
                },
                {
                    "type": "string",
                    "id": "#compute-pbc.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.PBC.txt')"
                    },
                    "id": "#compute-pbc.cwl/pbc"
                }
            ],
            "baseCommand": [
                "awk",
                "$4==1 {N1 += $3 - $2}; $4>=1 {Nd += $3 - $2} END {print N1/Nd}"
            ],
            "stdout": "$(inputs.output_filename + '.PBC.txt')",
            "id": "#compute-pbc.cwl"
        },
        {
            "class": "Workflow",
            "doc": "ChIP-seq - map - PCR Bottleneck Coefficients",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#pcr-bottleneck-coef.cwl/genome_sizes"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/input_bam_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/input_output_filenames"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/bg"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/genome_sizes",
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/g"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/input_bam_files",
                            "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/ibam"
                        }
                    ],
                    "scatter": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/ibam",
                    "out": [
                        "#pcr-bottleneck-coef.cwl/bedtools_genomecov/output_bedfile"
                    ],
                    "id": "#pcr-bottleneck-coef.cwl/bedtools_genomecov"
                },
                {
                    "run": "#compute-pbc.cwl",
                    "in": [
                        {
                            "source": "#pcr-bottleneck-coef.cwl/bedtools_genomecov/output_bedfile",
                            "id": "#pcr-bottleneck-coef.cwl/compute_pbc/bedgraph_file"
                        },
                        {
                            "source": "#pcr-bottleneck-coef.cwl/input_output_filenames",
                            "id": "#pcr-bottleneck-coef.cwl/compute_pbc/output_filename"
                        }
                    ],
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#pcr-bottleneck-coef.cwl/compute_pbc/bedgraph_file",
                        "#pcr-bottleneck-coef.cwl/compute_pbc/output_filename"
                    ],
                    "out": [
                        "#pcr-bottleneck-coef.cwl/compute_pbc/pbc"
                    ],
                    "id": "#pcr-bottleneck-coef.cwl/compute_pbc"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#pcr-bottleneck-coef.cwl/compute_pbc/pbc",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#pcr-bottleneck-coef.cwl/pbc_file"
                }
            ],
            "id": "#pcr-bottleneck-coef.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/picard",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "BARCODE_TAG=",
                        "separate": false,
                        "position": 5
                    },
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default false).",
                    "id": "#picard-MarkDuplicates.cwl/barcode_tag"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "$('INPUT=' + self.path)",
                        "shellQuote": false
                    },
                    "doc": "One or more input SAM or BAM files to analyze. Must be coordinate sorted.",
                    "id": "#picard-MarkDuplicates.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "id": "#picard-MarkDuplicates.cwl/java_opts"
                },
                {
                    "type": "string",
                    "default": "dedup_metrics.txt",
                    "doc": "Suffix used to create the metrics output file (Default: dedup_metrics.txt)",
                    "id": "#picard-MarkDuplicates.cwl/metrics_suffix"
                },
                {
                    "type": "string",
                    "doc": "Output filename used as basename",
                    "id": "#picard-MarkDuplicates.cwl/output_filename"
                },
                {
                    "type": "string",
                    "default": "dedup.bam",
                    "doc": "Suffix used to identify the output file (Default: dedup.bam)",
                    "id": "#picard-MarkDuplicates.cwl/output_suffix"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-jar"
                    },
                    "doc": "Path to the picard.jar file",
                    "id": "#picard-MarkDuplicates.cwl/picard_jar_path"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "valueFrom": "$('REMOVE_DUPLICATES=' + self)",
                        "position": 5
                    },
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default false).",
                    "id": "#picard-MarkDuplicates.cwl/remove_duplicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename  + '.' + inputs.output_suffix)"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_dedup_bam_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.' + inputs.metrics_suffix)"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_metrics_file"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "arguments": [
                {
                    "valueFrom": "MarkDuplicates",
                    "position": 3
                },
                {
                    "valueFrom": "$('OUTPUT=' + inputs.output_filename + '.' + inputs.output_suffix)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('METRICS_FILE='+inputs.output_filename + '.' + inputs.metrics_suffix)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('TMP_DIR='+runtime.tmpdir)",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('USE_JDK_DEFLATER=true')",
                    "position": 5,
                    "shellQuote": false
                },
                {
                    "valueFrom": "$('USE_JDK_INFLATER=true')",
                    "position": 5,
                    "shellQuote": false
                }
            ],
            "id": "#picard-MarkDuplicates.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Usage: c_curve [OPTIONS] <sorted-bed-file>\n\nOptions:\n  -o, -output   yield output file (default: stdout) \n  -s, -step     step size in extrapolations (default: 1e+06) \n  -v, -verbose  print more information \n  -P, -pe       input is paired end read file \n  -H, -hist     input is a text file containing the observed histogram \n  -V, -vals     input is a text file containing only the observed counts \n  -B, -bam      input is in BAM format \n  -l, -seg_len  maximum segment length when merging paired end bam reads \n                (default: 5000) \n\nHelp options:\n  -?, -help     print this help message \n      -about    print about message",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/preseq:2.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "-bam      input is in BAM format \n",
                    "id": "#preseq-c_curve.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-H"
                    },
                    "doc": "-hist     input is a text file containing the observed histogram \n",
                    "id": "#preseq-c_curve.cwl/H"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-V"
                    },
                    "doc": "-vals     input is a text file containing only the observed counts \n",
                    "id": "#preseq-c_curve.cwl/V"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sorted bed or BAM file",
                    "id": "#preseq-c_curve.cwl/input_sorted_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "-seg_len  maximum segment length when merging paired end bam reads \n(default: 5000)\nHelp options:\n-?, -help     print this help message\n-about    print about message\n",
                    "id": "#preseq-c_curve.cwl/l"
                },
                {
                    "type": "string",
                    "id": "#preseq-c_curve.cwl/output_file_basename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-P"
                    },
                    "doc": "-pe       input is paired end read file \n",
                    "id": "#preseq-c_curve.cwl/pe"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "-step     step size in extrapolations (default: 1e+06) \n",
                    "id": "#preseq-c_curve.cwl/s"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "-verbose  print more information \n",
                    "id": "#preseq-c_curve.cwl/v"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_basename + '.preseq_c_curve.txt')"
                    },
                    "id": "#preseq-c_curve.cwl/output_file"
                }
            ],
            "baseCommand": [
                "preseq",
                "c_curve"
            ],
            "stdout": "$(inputs.output_file_basename + '.preseq_c_curve.txt')",
            "id": "#preseq-c_curve.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get number of processed reads from Bowtie log.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {},
                    "id": "#preseq-percent-uniq-reads.cwl/preseq_c_curve_outfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.preseq_c_curve_outfile.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.percentage_unique_reads.txt')"
                    },
                    "id": "#preseq-percent-uniq-reads.cwl/output"
                }
            ],
            "baseCommand": "percent-uniq-reads-from-preseq.sh",
            "stdout": "$(inputs.preseq_c_curve_outfile.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.percentage_unique_reads.txt')",
            "id": "#preseq-percent-uniq-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-filter-unmapped.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-filter-unmapped.cwl/nthreads"
                },
                {
                    "type": "string",
                    "doc": "Basename for the output file",
                    "id": "#samtools-filter-unmapped.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename + '.accepted_hits.bam')"
                    },
                    "doc": "Filter unmapped reads in aligned file",
                    "id": "#samtools-filter-unmapped.cwl/filtered_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-F",
                "4",
                "-b",
                "-h"
            ],
            "stdout": "$(inputs.output_filename + '.accepted_hits.bam')",
            "id": "#samtools-filter-unmapped.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.bam)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "Bam file (it should be indexed)",
                    "id": "#samtools-idxstats.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "Idxstats output file. TAB-delimited with each line consisting of reference\nsequence name, sequence length, # mapped reads and # unmapped reads\n",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename + \".idxstats\")"
                    },
                    "id": "#samtools-idxstats.cwl/idxstats_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "idxstats"
            ],
            "stdout": "$(inputs.bam.basename + \".idxstats\")",
            "id": "#samtools-idxstats.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.input_file)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-index.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "doc": "Indexed BAM file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename)"
                    },
                    "secondaryFiles": ".bai",
                    "id": "#samtools-index.cwl/indexed_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_file.basename + '.bai')",
                    "position": 2
                }
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-sort.cwl/input_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "Sort by read name",
                    "id": "#samtools-sort.cwl/n"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": ".sorted.bam",
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-sort.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)"
                    },
                    "doc": "Sorted aligned file",
                    "id": "#samtools-sort.cwl/sorted_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 3,
                    "prefix": "-T"
                }
            ],
            "id": "#samtools-sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "only include reads with none of the bits set in INT set in FLAG [0]",
                    "id": "#samtools-view.cwl/F"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-L"
                    },
                    "doc": "FILE  only include reads overlapping this BED FILE [null]",
                    "id": "#samtools-view.cwl/L"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Input format autodetected",
                    "id": "#samtools-view.cwl/S"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-b"
                    },
                    "doc": "output BAM",
                    "id": "#samtools-view.cwl/b"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "only include reads with all bits set in INT set in FLAG [0]",
                    "id": "#samtools-view.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-h"
                    },
                    "doc": "Include header in output",
                    "id": "#samtools-view.cwl/header"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "File to be converted to BAM with samtools",
                    "id": "#samtools-view.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used",
                    "id": "#samtools-view.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output file name. If not specified, the basename of the input file with the suffix specified in the suffix argument will be used.",
                    "id": "#samtools-view.cwl/outfile_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "only include reads with mapping quality >= INT [0]",
                    "id": "#samtools-view.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-view.cwl/suffix"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "uncompressed BAM output (implies -b)",
                    "id": "#samtools-view.cwl/u"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outfile_name) return inputs.outfile_name;\n  var suffix = inputs.b ? '.bam' : '.sam';\n  suffix = inputs.suffix || suffix;\n  return inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + suffix\n}\n"
                    },
                    "doc": "Aligned file in SAM or BAM format",
                    "id": "#samtools-view.cwl/outfile"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "stdout": "${\n   if (inputs.outfile_name) return inputs.outfile_name;\n   var suffix = inputs.b ? '.bam' : '.sam';\n   suffix = inputs.suffix || suffix;\n   return inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + suffix\n}\n",
            "id": "#samtools-view.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "Input format autodetected",
                    "id": "#samtools2bam.cwl/S"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "File to be converted to BAM with samtools",
                    "id": "#samtools2bam.cwl/input_file"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used",
                    "id": "#samtools2bam.cwl/nthreads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bam')"
                    },
                    "doc": "Aligned file in BAM format",
                    "id": "#samtools2bam.cwl/bam_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.bam')",
            "id": "#samtools2bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Count number of dedup-ed reads used in peak calling",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-reads-after-filtering.cwl/peak_xls_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))"
                    },
                    "id": "#count-reads-after-filtering.cwl/read_count_file"
                }
            ],
            "baseCommand": "count-filtered-reads-macs2.sh",
            "stdout": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))",
            "id": "#count-reads-after-filtering.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/macs2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--SPMR"
                    },
                    "doc": "If True, MACS will save signal per million reads for fragment pileup profiles. Require --bdg to be set. Default: False ",
                    "id": "#macs2-callpeak.cwl/SPMR"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bdg"
                    },
                    "doc": "Whether or not to save extended fragment pileup, and local lambda tracks (two files) at every bp into a bedGraph file. DEFAULT: True",
                    "id": "#macs2-callpeak.cwl/bdg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad"
                    },
                    "doc": "If set, MACS will try to call broad peaks by linking nearby highly enriched regions. The linking region is controlled by another cutoff through --linking-cutoff. The maximum linking region length is 4 times of d from MACS. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/broad"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad-cutoff"
                    },
                    "doc": "BROADCUTOFF\nCutoff for broad region. This option is not available\nunless --broad is set. If -p is set, this is a pvalue\ncutoff, otherwise, it's a qvalue cutoff. DEFAULT: 0.1\n",
                    "id": "#macs2-callpeak.cwl/broad-cutoff"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--buffer-size"
                    },
                    "doc": "BUFFER_SIZE\nBuffer size for incrementally increasing internal\narray size to store reads alignment information. In\nmost cases, you don't have to change this parameter.\nHowever, if there are large number of\nchromosomes/contigs/scaffolds in your alignment, it's\nrecommended to specify a smaller buffer size in order\nto decrease memory usage (but it will take longer time\nto read alignment files). Minimum memory requested for\nreading an alignment file is about # of CHROMOSOME *\nBUFFER_SIZE * 2 Bytes. DEFAULT: 100000\n",
                    "id": "#macs2-callpeak.cwl/buffer-size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bw"
                    },
                    "doc": "BW               Band width for picking regions to compute fragment\nsize. This value is only used while building the\nshifting model. DEFAULT: 300\n",
                    "id": "#macs2-callpeak.cwl/bw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--call-summits"
                    },
                    "doc": "If set, MACS will use a more sophisticated signal processing approach to find subpeak summits in each enriched peak region. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/call-summits"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--control"
                    },
                    "doc": "Control sample file.",
                    "id": "#macs2-callpeak.cwl/control"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--cutoff-analysis"
                    },
                    "doc": "While set, MACS2 will analyze number or total length of peaks that can be called by different p-value cutoff then output a summary table to help user decide a better cutoff. The table will be saved in NAME_cutoff_analysis.txt file. Note, minlen and maxgap may affect the results. WARNING: May take ~30 folds longer time to finish. DEFAULT: False Post-processing options: ",
                    "id": "#macs2-callpeak.cwl/cutoff-analysis"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--down-sample"
                    },
                    "doc": "When set, random sampling method will scale down the bigger sample. By default, MACS uses linear scaling. Warning: This option will make your result unstable and irreproducible since each time, random reads would be selected. Consider to use 'randsample' script instead. <not implmented>If used together with --SPMR, 1 million unique reads will be randomly picked.</not implemented> Caution: due to the implementation, the final number of selected reads may not be as you expected! DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/down-sample"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extsize"
                    },
                    "doc": "The arbitrary extension size in bp. When nomodel is  true, MACS will use this value as fragment size to  extend each read towards 3' end, then pile them up.  It's exactly twice the number of obsolete SHIFTSIZE.  In previous language, each read is moved 5'->3'  direction to middle of fragment by 1/2 d, then  extended to both direction with 1/2 d. This is  equivalent to say each read is extended towards 5'->3'  into a d size fragment. DEFAULT: 200. EXTSIZE and  SHIFT can be combined when necessary. Check SHIFT  option.",
                    "id": "#macs2-callpeak.cwl/extsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fe-cutoff"
                    },
                    "doc": "FECUTOFF  When set, the value will be used to filter out peaks\nwith low fold-enrichment. Note, MACS2 use 1.0 as\npseudocount while calculating fold-enrichment.\nDEFAULT: 1.0\n",
                    "id": "#macs2-callpeak.cwl/fe-cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fix-bimodal"
                    },
                    "doc": "Whether turn on the auto pair model process. If set, when MACS failed to build paired model, it will use the nomodel settings, the --exsize parameter to extend each tags towards 3' direction. Not to use this automate fixation is a default behavior now. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/fix-bimodal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "-f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE}, --format {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE} Format of tag file, \"AUTO\", \"BED\" or \"ELAND\" or \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\" or \"BOWTIE\" or \"BAMPE\". The default AUTO option will let MACS decide which format the file is. Note that MACS can't detect \"BAMPE\" or \"BEDPE\" format with \"AUTO\", and you have to implicitly specify the format for \"BAMPE\" and \"BEDPE\". DEFAULT: \"AUTO\".",
                    "id": "#macs2-callpeak.cwl/format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "Effective genome size. It can be 1.0e+9 or 1000000000,  or shortcuts:'hs' for human (2.7e9), 'mm' for mouse  (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for  fruitfly (1.2e8), Default:hs.",
                    "id": "#macs2-callpeak.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--keep-dup"
                    },
                    "doc": "KEEPDUPLICATES\nIt controls the MACS behavior towards duplicate tags\nat the exact same location -- the same coordination\nand the same strand. The 'auto' option makes MACS\ncalculate the maximum tags at the exact same location\nbased on binomal distribution using 1e-5 as pvalue\ncutoff; and the 'all' option keeps every tags. If an\ninteger is given, at most this number of tags will be\nkept at the same location. The default is to keep one\ntag at the same location. Default: 1\n",
                    "id": "#macs2-callpeak.cwl/keep-dup"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--llocal"
                    },
                    "doc": "LARGELOCAL   The large nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the surround\nbias. If you set this to 0, MACS will skip llocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT:\n10000.\n",
                    "id": "#macs2-callpeak.cwl/llocal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "MFOLD MFOLD, --mfold MFOLD MFOLD\nSelect the regions within MFOLD range of high-\nconfidence enrichment ratio against background to\nbuild model. Fold-enrichment in regions must be lower\nthan upper limit, and higher than the lower limit. Use\nas \"-m 10 30\". DEFAULT:5 50\n",
                    "id": "#macs2-callpeak.cwl/m"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nolambda"
                    },
                    "doc": "If True, MACS will use fixed background lambda as local lambda for every peak region. Normally, MACS calculates a dynamic local lambda to reflect the local bias due to potential chromatin structure. ",
                    "id": "#macs2-callpeak.cwl/nolambda"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nomodel"
                    },
                    "doc": "\t Whether or not to build the shifting model. If True,  MACS will not build model. by default it means  shifting size = 100, try to set extsize to change it.  DEFAULT: False",
                    "id": "#macs2-callpeak.cwl/nomodel"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-p"
                    },
                    "doc": "Pvalue cutoff for peak detection. DEFAULT: not set.  -q, and -p are mutually exclusive. If pvalue cutoff is  set, qvalue will not be calculated and reported as -1  in the final .xls file..",
                    "id": "#macs2-callpeak.cwl/p"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "Minimum FDR (q-value) cutoff for peak detection. DEFAULT: 0.05. -q, and -p are mutually exclusive.",
                    "id": "#macs2-callpeak.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ratio"
                    },
                    "doc": "RATIO         When set, use a custom scaling ratio of ChIP/control\n(e.g. calculated using NCIS) for linear scaling.\nDEFAULT: ingore\n",
                    "id": "#macs2-callpeak.cwl/ratio"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "TSIZE, --tsize TSIZE\nTag size. This will overide the auto detected tag\nsize. DEFAULT: Not set\n",
                    "id": "#macs2-callpeak.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seed"
                    },
                    "doc": "SEED           Set the random seed while down sampling data. Must be\na non-negative integer in order to be effective.\nDEFAULT: not set\n",
                    "id": "#macs2-callpeak.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--shift"
                    },
                    "doc": "(NOT the legacy --shiftsize option!) The arbitrary shift in bp. Use discretion while setting it other than default value. When NOMODEL is set, MACS will use this value to move cutting ends (5') towards 5'->3' direction then apply EXTSIZE to extend them to fragments. When this value is negative, ends will be moved toward 3'->5' direction. Recommended to keep it as default 0 for ChIP-Seq datasets, or -1 * half of EXTSIZE together with EXTSIZE option for detecting enriched cutting loci such as certain DNAseI-Seq datasets. Note, you can't set values other than 0 if format is BAMPE for paired-end data. DEFAULT: 0.",
                    "id": "#macs2-callpeak.cwl/shift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--slocal"
                    },
                    "doc": "SMALLLOCAL   The small nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the bias near\nthe peak summit region. Invalid if there is no control\ndata. If you set this to 0, MACS will skip slocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT: 1000\n",
                    "id": "#macs2-callpeak.cwl/slocal"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--to-large"
                    },
                    "doc": "When set, scale the small sample up to the bigger sample. By default, the bigger dataset will be scaled down towards the smaller dataset, which will lead to smaller p/qvalues and more specific results. Keep in mind that scaling down will bring down background noise more. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/to-large"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trackline"
                    },
                    "doc": "Tells MACS to include trackline with bedGraph files. To include this trackline while displaying bedGraph at UCSC genome browser, can show name and description of the file as well. However my suggestion is to convert bedGraph to bigWig, then show the smaller and faster binary bigWig file at UCSC genome browser, as well as downstream analysis. Require --bdg to be set. Default: Not include trackline. ",
                    "id": "#macs2-callpeak.cwl/trackline"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--treatment"
                    },
                    "doc": "Treatment sample file(s). If multiple files are given as -t A B C, then they will all be read and pooled together. IMPORTANT: the first sample will be used as the outputs basename.",
                    "id": "#macs2-callpeak.cwl/treatment"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "VERBOSE_LEVEL     Set verbose level of runtime message. 0: only show\ncritical message, 1: show additional warning message,\n2: show process information, 3: show debug messages.\nDEFAULT:2\n",
                    "id": "#macs2-callpeak.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_treat_pileup.bdg')"
                    },
                    "doc": "Bedgraph with extended fragment pileup.",
                    "id": "#macs2-callpeak.cwl/output_ext_frag_bdg_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.*Peak')",
                        "outputEval": "$(self[0])"
                    },
                    "doc": "Peak calling output file in narrowPeak|broadPeak format.",
                    "id": "#macs2-callpeak.cwl/output_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_summits.bed')"
                    },
                    "doc": "Peaks summits bedfile.",
                    "id": "#macs2-callpeak.cwl/output_peak_summits_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.xls')"
                    },
                    "doc": "Peaks information/report file.",
                    "id": "#macs2-callpeak.cwl/output_peak_xls_file"
                }
            ],
            "baseCommand": [
                "macs2",
                "callpeak"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, ''))",
                    "prefix": "-n",
                    "position": 1
                }
            ],
            "id": "#macs2-callpeak.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extract mapped reads from BAM file using Samtools flagstat command",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-extract-number-mapped-reads.cwl/input_bam_file"
                },
                {
                    "type": "string",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "doc": "Samtools Flagstat report file",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": [
                "samtools",
                "flagstat"
            ],
            "arguments": [
                {
                    "valueFrom": " | head -n1 | cut -f 1 -d ' '",
                    "position": 10000,
                    "shellQuote": false
                }
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
            "id": "#samtools-extract-number-mapped-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter BAM file to only include reads overlapping with a BED file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-L"
                    },
                    "doc": "Bedfile used to only include reads overlapping this BED FILE",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bedfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')"
                    },
                    "doc": "Filtered aligned BAM file by BED coordinates file",
                    "id": "#samtools-filter-in-bedfile.cwl/filtered_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b",
                "-h"
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')",
            "id": "#samtools-filter-in-bedfile.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts read count from fastqc_data.txt",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastqc-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastqc-reads.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc-read_count.txt')"
                    },
                    "id": "#count-fastqc-reads.cwl/output_fastqc_read_count"
                }
            ],
            "baseCommand": "count-fastqc_data-reads.sh",
            "stdout": "$(inputs.input_basename + '.fastqc-read_count.txt')",
            "id": "#count-fastqc-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compares 2 files",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--brief",
                        "position": 3
                    },
                    "id": "#diff.cwl/brief"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#diff.cwl/file1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#diff.cwl/file2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    },
                    "id": "#diff.cwl/result"
                }
            ],
            "baseCommand": "diff",
            "stdout": "stdout.txt",
            "id": "#diff.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Unzips a zipped fastqc report and returns the fastqc_data.txt file. Unzips the file to pipe and uses redirection",
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "*/fastqc_data.txt",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#extract_fastqc_data.cwl/extract_pattern"
                },
                {
                    "type": "string",
                    "id": "#extract_fastqc_data.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#extract_fastqc_data.cwl/input_qc_report_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-p",
                        "position": 1
                    },
                    "id": "#extract_fastqc_data.cwl/pipe"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc_data.txt')"
                    },
                    "id": "#extract_fastqc_data.cwl/output_fastqc_data_file"
                }
            ],
            "baseCommand": "unzip",
            "stdout": "$(inputs.input_basename + '.fastqc_data.txt')",
            "id": "#extract_fastqc_data.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "fastq",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--format"
                    },
                    "id": "#fastqc.cwl/format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fastqc.cwl/input_fastq_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--noextract",
                        "position": 2
                    },
                    "id": "#fastqc.cwl/noextract"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--threads"
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fastq_file.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.gz$/, '').replace(/\\.[^/.]+$/, '') + \"_fastqc.zip\")"
                    },
                    "id": "#fastqc.cwl/output_qc_report_file"
                }
            ],
            "baseCommand": "fastqc",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--dir",
                    "position": 5
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o",
                    "position": 5
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "reddylab/overrepresented_sequence_extract:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Adapters file in fasta format",
                    "id": "#overrepresented_sequence_extract.cwl/default_adapters_file"
                },
                {
                    "type": "string",
                    "doc": "Name of the sample - used as a base name for generating output files",
                    "id": "#overrepresented_sequence_extract.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "fastqc_data.txt file from a fastqc report",
                    "id": "#overrepresented_sequence_extract.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.custom_adapters.fasta')"
                    },
                    "id": "#overrepresented_sequence_extract.cwl/output_custom_adapters"
                }
            ],
            "baseCommand": "overrepresented_sequence_extract.py",
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_basename + '.custom_adapters.fasta')",
                    "position": 3
                }
            ],
            "id": "#overrepresented_sequence_extract.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Tool:   bedGraphToBigWig v 4 - Convert a bedGraph file to bigWig format.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "\tbed_graph is a four column file in the format: <chrom> <start> <end> <value>\n",
                    "id": "#bedGraphToBigWig.cwl/bed_graph"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "\tgenome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedGraphToBigWig.cwl/genome_sizes"
                },
                {
                    "type": "string",
                    "default": ".bw",
                    "id": "#bedGraphToBigWig.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedGraphToBigWig.cwl/output_bigwig"
                }
            ],
            "baseCommand": "bedGraphToBigWig",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_graph.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
                    "position": 3
                }
            ],
            "id": "#bedGraphToBigWig.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "bedSort - Sort a .bed file by chrom,chromStart\nusage:\n   bedSort in.bed out.bed\nin.bed and out.bed may be the same.\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bed or bedGraph file to be sorted",
                    "id": "#bedSort.cwl/bed_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")"
                    },
                    "id": "#bedSort.cwl/bed_file_sorted"
                }
            ],
            "baseCommand": "bedSort",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed_file.path.replace(/^.*[\\\\\\/]/, '') + \"_sorted\")",
                    "position": 2
                }
            ],
            "id": "#bedSort.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "\"bedToBigBed v. 2.7 - Convert bed file to bigBed. (BigBed version: 4)\nusage:\n   bedToBigBed in.bed chrom.sizes out.bb\nWhere in.bed is in one of the ascii bed formats, but not including track lines\nand chrom.sizes is two column: <chromosome name> <size in bases>\nand out.bb is the output indexed big bed file.\nUse the script: fetchChromSizes to obtain the actual chrom.sizes information\nfrom UCSC, please do not make up a chrom sizes from your own information.\nThe in.bed file must be sorted by chromosome,start,\n  to sort a bed file, use the unix sort command:\n     sort -k1,1 -k2,2n unsorted.bed > sorted.bed\"\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/ucsc-kentutils:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-as=",
                        "separate": false
                    },
                    "doc": "-as=fields.as - If you have non-standard \"bedPlus\" fields, it's great to put a definition\n                 of each field in a row in AutoSql format here.1)\n",
                    "id": "#bedToBigBed.cwl/as"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input bed file",
                    "id": "#bedToBigBed.cwl/bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-blockSize=",
                        "separate": false
                    },
                    "doc": "-blockSize=N - Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#bedToBigBed.cwl/blockSize"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-extraIndex=",
                        "itemSeparator": ","
                    },
                    "doc": "-extraIndex=fieldList - If set, make an index on each field in a comma separated list\n   extraIndex=name and extraIndex=name,id are commonly used.\n",
                    "id": "#bedToBigBed.cwl/extraIndex"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "genome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedToBigBed.cwl/genome_sizes"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-itemsPerSlot=",
                        "separate": false
                    },
                    "doc": "-itemsPerSlot=N - Number of data points bundled at lowest level. Default 512\n",
                    "id": "#bedToBigBed.cwl/itemsPerSlot"
                },
                {
                    "type": "string",
                    "default": ".bb",
                    "id": "#bedToBigBed.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-tab - If set, expect fields to be tab separated, normally expects white space separator.\n",
                    "id": "#bedToBigBed.cwl/tab"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-type=",
                        "separate": false
                    },
                    "doc": "-type=bedN[+[P]] :\n                N is between 3 and 15,\n                optional (+) if extra \"bedPlus\" fields,\n                optional P specifies the number of extra fields. Not required, but preferred.\n                Examples: -type=bed6 or -type=bed6+ or -type=bed6+3\n                (see http://genome.ucsc.edu/FAQ/FAQformat.html#format1)\n",
                    "id": "#bedToBigBed.cwl/type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-unc - If set, do not use compression.\n",
                    "id": "#bedToBigBed.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed.path.replace(/^.*[\\\\\\/]/, '')+ inputs.output_suffix)"
                    },
                    "id": "#bedToBigBed.cwl/bigbed"
                }
            ],
            "baseCommand": "bedToBigBed",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)",
                    "position": 4
                }
            ],
            "id": "#bedToBigBed.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "usage: An example usage is:$ bamCoverage -b reads.bam -o coverage.bw\n\nThis tool takes an alignment of reads or fragments as input (BAM file) and\ngenerates a coverage track (bigWig or bedGraph) as output. The coverage is\ncalculated as the number of reads per bin, where bins are short consecutive\ncounting windows of a defined size. It is possible to extended the length of\nthe reads to better reflect the actual fragment length. *bamCoverage* offers\nnormalization by scaling factor, Reads Per Kilobase per Million mapped reads\n(RPKM), and 1x depth (reads per genome coverage, RPGC).\nRequired arguments:\n  --bam BAM file, -b BAM file\n                        BAM file to process (default: None)\nOutput:\n  --outFileName FILENAME, -o FILENAME\n                        Output file name. (default: None)\n  --outFileFormat {bigwig,bedgraph}, -of {bigwig,bedgraph}\n                        Output file type. Either \"bigwig\" or \"bedgraph\".\n                        (default: bigwig)\nOptional arguments:\n  --help, -h            show this help message and exit\n  --scaleFactor SCALEFACTOR\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the \u2013binSize is set to 20 and the \u2013smoothLength is\n                        set to 60, then, for each bin, the average of the bin\n                        and its left and right neighbors is considered.\n                        Any value smaller than \u2013binSize will be ignored and\n                        no smoothing will be applied. (default: 1.0)\n  --MNase               Determine nucleosome positions from MNase-seq data.\n                        Only 3 nucleotides at the center of each fragment are\n                        counted. The fragment ends are defined by the two mate\n                        reads. Only fragment lengthsbetween 130 - 200 bp are\n                        considered to avoid dinucleosomes or other\n                        artifacts.*NOTE*: Requires paired-end data. A bin size\n                        of 1 is recommended. (default: False)\n  --filterRNAstrand {forward,reverse}\n                        Selects RNA-seq reads (single-end or paired-end) in\n                        the given strand. (default: None)\n  --version             show program's version number and exit\n  --binSize INT bp, -bs INT bp\n                        Size of the bins, in bases, for the output of the\n                        bigwig/bedgraph file. (default: 50)\n  --region CHR:START:END, -r CHR:START:END\n                        Region of the genome to limit the operation to - this\n                        is useful when testing parameters to reduce the\n                        computing time. The format is chr:start:end, for\n                        example --region chr10 or --region\n                        chr10:456700:891000. (default: None)\n  --blackListFileName BED file, -bl BED file\n                        A BED file containing regions that should be excluded\n                        from all analyses. Currently this works by rejecting\n                        genomic chunks that happen to overlap an entry.\n                        Consequently, for BAM files, if a read partially\n                        overlaps a blacklisted region or a fragment spans over\n                        it, then the read/fragment might still be considered.\n                        (default: None)\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors. (default: max/2)\n  --verbose, -v         Set to see processing messages. (default: False)\nRead coverage normalization options:\n  --normalizeTo1x EFFECTIVE GENOME SIZE LENGTH\n                        Report read coverage normalized to 1x sequencing depth\n                        (also known as Reads Per Genomic Content (RPGC)).\n                        Sequencing depth is defined as: (total number of\n                        mapped reads * fragment length) / effective genome\n                        size. The scaling factor used is the inverse of the\n                        sequencing depth computed for the sample to match the\n                        1x coverage. To use this option, the effective genome\n                        size has to be indicated after the option. The\n                        effective genome size is the portion of the genome\n                        that is mappable. Large fractions of the genome are\n                        stretches of NNNN that should be discarded. Also, if\n                        repetitive regions were not included in the mapping of\n                        reads, the effective genome size needs to be adjusted\n                        accordingly. Common values are: mm9: 2,150,570,000;\n                        hg19:2,451,960,000; dm3:121,400,000 and\n                        ce10:93,260,000. See Table 2 of http://www.plosone.org\n                        /article/info:doi/10.1371/journal.pone.0030377 or http\n                        ://www.nature.com/nbt/journal/v27/n1/fig_tab/nbt.1518_\n                        T1.html for several effective genome sizes. (default:\n                        None)\n--ignoreForNormalization IGNOREFORNORMALIZATION [IGNOREFORNORMALIZATION ...]\n                        A list of space-delimited chromosome names containing\n                        those chromosomes that should be excluded for\n                        computing the normalization. This is useful when\n                        considering samples with unequal coverage across\n                        chromosomes, like male samples. An usage examples is\n                        --ignoreForNormalization chrX chrM. (default: None)\n  --skipNonCoveredRegions, --skipNAs\n                        This parameter determines if non-covered regions\n                        (regions without overlapping reads) in a BAM file\n                        should be skipped. The default is to treat those\n                        regions as having a value of zero. The decision to\n                        skip non-covered regions depends on the interpretation\n                        of the data. Non-covered regions may represent, for\n                        example, repetitive regions that should be skipped.\n                        (default: False)\n  --smoothLength INT bp\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the --binSize is set to 20 and the --smoothLength\n                        is set to 60, then, for each bin, the average of the\n                        bin and its left and right neighbors is considered.\n                        Any value smaller than --binSize will be ignored and\n                        no smoothing will be applied. (default: None)\nRead processing options:\n  --extendReads [INT bp], -e [INT bp]\n                        This parameter allows the extension of reads to\n                        fragment size. If set, each read is extended, without\n                        exception. *NOTE*: This feature is generally NOT\n                        recommended for spliced-read data, such as RNA-seq, as\n                        it would extend reads over skipped regions. *Single-\n                        end*: Requires a user specified value for the final\n                        fragment length. Reads that already exceed this\n                        fragment length will not be extended. *Paired-end*:\n                        Reads with mates are always extended to match the\n                        fragment size defined by the two read mates. Unmated\n                        reads, mate reads that map too far apart (>4x fragment\n                        length) or even map to different chromosomes are\n                        treated like single-end reads. The input of a fragment\n                        length value is optional. If no value is specified, it\n                        is estimated from the data (mean of the fragment size\n                        of all mate reads). (default: False)\n  --ignoreDuplicates    If set, reads that have the same orientation and start\n                        position will be considered only once. If reads are\n                        paired, the mate's position also has to coincide to\n                        ignore a read. (default: False)\n  --minMappingQuality INT\n                        If set, only reads that have a mapping quality score\n                        of at least this are considered. (default: None)\n  --centerReads         By adding this option, reads are centered with respect\n                        to the fragment length. For paired-end data, the read\n                        is centered at the fragment length defined by the two\n                        ends of the fragment. For single-end data, the given\n                        fragment length is used. This option is useful to get\n                        a sharper signal around enriched regions. (default:\n                        False)\n  --samFlagInclude INT  Include reads based on the SAM flag. For example, to\n                        get only reads that are the first mate, use a flag of\n                        64. This is useful to count properly paired reads only\n                        once, as otherwise the second mate will be also\n                        considered for the coverage. (default: None)\n  --samFlagExclude INT  Exclude reads based on the SAM flag. For example, to\n                        get only reads that map to the forward strand, use\n                        --samFlagExclude 16, where 16 is the SAM flag for\n                        reads that map to the reverse strand. (default: None)\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/deeptools:3.0.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--MNase"
                    },
                    "doc": "Determine nucleosome positions from MNase-seq data.\nOnly 3 nucleotides at the center of each fragment are\ncounted. The fragment ends are defined by the two mate\nreads. Only fragment lengthsbetween 130 - 200 bp are\nconsidered to avoid dinucleosomes or other\nartifacts.*NOTE*: Requires paired-end data. A bin size\nof 1 is recommended. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/MNase"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "doc": "BAM file to process ",
                    "id": "#deeptools-bamcoverage.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--binSize"
                    },
                    "doc": "INT bp\nSize of the bins, in bases, for the output of the\nbigwig/bedgraph file. (default: 50)\n",
                    "id": "#deeptools-bamcoverage.cwl/binSize"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--blackListFileName"
                    },
                    "doc": "BED file\nA BED file containing regions that should be excluded\nfrom all analyses. Currently this works by rejecting\ngenomic chunks that happen to overlap an entry.\nConsequently, for BAM files, if a read partially\noverlaps a blacklisted region or a fragment spans over\nit, then the read/fragment might still be considered.\n(default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/blackListFileName"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--centerReads"
                    },
                    "doc": "By adding this option, reads are centered with respect\nto the fragment length. For paired-end data, the read\nis centered at the fragment length defined by the two\nends of the fragment. For single-end data, the given\nfragment length is used. This option is useful to get\na sharper signal around enriched regions. (default:\nFalse)\n",
                    "id": "#deeptools-bamcoverage.cwl/centerReads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extendReads"
                    },
                    "doc": "INT bp\nThis parameter allows the extension of reads to\nfragment size. If set, each read is extended, without\nexception. *NOTE*: This feature is generally NOT\nrecommended for spliced-read data, such as RNA-seq, as\nit would extend reads over skipped regions. *Single-\nend*: Requires a user specified value for the final\nfragment length. Reads that already exceed this\nfragment length will not be extended. *Paired-end*:\nReads with mates are always extended to match the\nfragment size defined by the two read mates. Unmated\nreads, mate reads that map too far apart (>4x fragment\nlength) or even map to different chromosomes are\ntreated like single-end reads. The input of a fragment\nlength value is optional. If no value is specified, it\nis estimated from the data (mean of the fragment size\nof all mate reads). (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/extendReads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--filterRNAstrand"
                    },
                    "doc": "{forward,reverse}\nSelects RNA-seq reads (single-end or paired-end) in\nthe given strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/filterRNAstrand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreDuplicates"
                    },
                    "doc": "If set, reads that have the same orientation and start\nposition will be considered only once. If reads are\npaired, the mate's position also has to coincide to\nignore a read. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreDuplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreForNormalization"
                    },
                    "doc": "A list of space-delimited chromosome names containing those chromosomes\nthat should be excluded for computing the normalization. This is useful\nwhen considering samples with unequal coverage across chromosomes, like\nmale samples. An usage examples is \u2013ignoreForNormalization chrX chrM.\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreForNormalization"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--minMappingQuality"
                    },
                    "doc": "INT\nIf set, only reads that have a mapping quality score\nof at least this are considered. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/minMappingQuality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--normalizeUsing"
                    },
                    "doc": "Possible choices: RPKM, CPM, BPM, RPGC\n\nUse one of the entered methods to normalize the number of reads per bin.\nBy default, no normalization is performed. RPKM = Reads Per Kilobase per\nMillion mapped reads; CPM = Counts Per Million mapped reads, same as\nCPM in RNA-seq; BPM = Bins Per Million mapped reads, same as TPM in\nRNA-seq; RPGC = reads per genomic content (1x normalization);\nMapped reads are considered after blacklist filtering (if applied).\nRPKM (per bin) = number of reads per bin / (number of mapped reads (in millions) * bin length (kb)).\nCPM (per bin) = number of reads per bin / number of mapped reads (in millions).\nBPM (per bin) = number of reads per bin / sum of all reads per bin (in millions).\nRPGC (per bin) = number of reads per bin / scaling factor for 1x average coverage.\nThis scaling factor, in turn, is determined from the sequencing depth:\n(total number of mapped reads * fragment length) / effective genome size.\nThe scaling factor used is the inverse of the sequencing depth\ncomputed for the sample to match the 1x coverage.\nThis option requires \u2013effectiveGenomeSize.\nEach read is considered independently, if you want to only count one\nmate from a pair in paired-end data, then use\nthe \u2013samFlagInclude/\u2013samFlagExclude options.\n",
                    "id": "#deeptools-bamcoverage.cwl/normalizeUsing"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "INT\nNumber of processors to use. Type \"max/2\" to use half\nthe maximum number of processors or \"max\" to use all\navailable processors. (default: max/2)\n",
                    "id": "#deeptools-bamcoverage.cwl/numberOfProcessors"
                },
                {
                    "type": "string",
                    "default": "bigwig",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileFormat"
                    },
                    "doc": "{bigwig,bedgraph}, -of {bigwig,bedgraph}\nOutput file type. Either \"bigwig\" or \"bedgraph\".\n(default: bigwig)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileFormat"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FILENAME\nOutput file name. (default: input BAM filename with bigwig [*.bw] or bedgraph [*.bdg] extension.)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Suffix used for output file (input BAM filename + suffix)",
                    "id": "#deeptools-bamcoverage.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region"
                    },
                    "doc": "CHR:START:END\nRegion of the genome to limit the operation to - this\nis useful when testing parameters to reduce the\ncomputing time. The format is chr:start:end, for\nexample --region chr10 or --region\nchr10:456700:891000. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagExclude"
                    },
                    "doc": "INT  \nExclude reads based on the SAM flag. For example, to\nget only reads that map to the forward strand, use\n--samFlagExclude 16, where 16 is the SAM flag for\nreads that map to the reverse strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagExclude"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagInclude"
                    },
                    "doc": "INT  \nInclude reads based on the SAM flag. For example, to\nget only reads that are the first mate, use a flag of\n64. This is useful to count properly paired reads only\nonce, as otherwise the second mate will be also\nconsidered for the coverage. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagInclude"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scaleFactor"
                    },
                    "doc": "The smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the \u2013binSize is set to 20 and the \u2013smoothLength is\nset to 60, then, for each bin, the average of the bin\nand its left and right neighbors is considered.\nAny value smaller than \u2013binSize will be ignored and\nno smoothing will be applied. (default: 1.0)\n",
                    "id": "#deeptools-bamcoverage.cwl/scaleFactor"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--skipNonCoveredRegions"
                    },
                    "doc": "--skipNonCoveredRegions, --skipNAs\nThis parameter determines if non-covered regions\n(regions without overlapping reads) in a BAM file\nshould be skipped. The default is to treat those\nregions as having a value of zero. The decision to\nskip non-covered regions depends on the interpretation\nof the data. Non-covered regions may represent, for\nexample, repetitive regions that should be skipped.\n(default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/skipNonCoveredRegions"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--smoothLength"
                    },
                    "doc": "INT bp\nThe smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the --binSize is set to 20 and the --smoothLength\nis set to 60, then, for each bin, the average of the\nbin and its left and right neighbors is considered.\nAny value smaller than --binSize will be ignored and\nno smoothing will be applied. (default: None)\nRead processing options:\n",
                    "id": "#deeptools-bamcoverage.cwl/smoothLength"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "--verbose         \nSet to see processing messages. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "show program's version number and exit",
                    "id": "#deeptools-bamcoverage.cwl/version"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }"
                    },
                    "id": "#deeptools-bamcoverage.cwl/output_bam_coverage"
                }
            ],
            "baseCommand": "bamCoverage",
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }",
                    "prefix": "--outFileName",
                    "position": 3
                }
            ],
            "id": "#deeptools-bamcoverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts best fragment length from SPP output text file",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-best-frag-length.cwl/input_spp_txt_file"
                }
            ],
            "outputs": [
                {
                    "type": "float",
                    "outputBinding": {
                        "glob": "best_frag_length",
                        "loadContents": true,
                        "outputEval": "$(Number(self[0].contents.replace('\\n', '')))"
                    },
                    "id": "#extract-best-frag-length.cwl/output_best_frag_length"
                }
            ],
            "baseCommand": "extract-best-frag-length.sh",
            "stdout": "best_frag_length",
            "id": "#extract-best-frag-length.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/spp",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-i=",
                        "separate": false
                    },
                    "doc": "<Input_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped) (FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/control_bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-fdr=",
                        "separate": false
                    },
                    "doc": "-fdr=<falseDisoveryRate> , false discovery rate threshold for peak calling",
                    "id": "#spp.cwl/fdr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-filtchr=",
                        "separate": false
                    },
                    "doc": "-filtchr=<chrnamePattern> , Pattern to use to remove tags that map to specific chromosomes e.g. _ will remove all tags that map to chromosomes with _ in their name",
                    "id": "#spp.cwl/filtchr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c=",
                        "separate": false
                    },
                    "doc": "<ChIP_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped)(FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-npeak=",
                        "separate": false
                    },
                    "doc": "-npeak=<numPeaks>, threshold on number of peaks to call",
                    "id": "#spp.cwl/npeak"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p=",
                        "separate": false
                    },
                    "doc": "-p=<nodes> , number of parallel processing nodes, default=0",
                    "id": "#spp.cwl/nthreads"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-rf"
                    },
                    "doc": "overwrite (force remove) output files in case they exist. Default: true",
                    "id": "#spp.cwl/rf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s=",
                        "separate": false
                    },
                    "doc": "-s=<min>:<step>:<max> , strand shifts at which cross-correlation is evaluated, default=-500:5:1500",
                    "id": "#spp.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savd=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\"; return null}"
                    },
                    "doc": "-savd=<rdatafile> OR -savd, save Rdata file",
                    "id": "#spp.cwl/savd"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savn=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\"; return null}"
                    },
                    "doc": "-savn=<narrowpeakfilename> OR -savn NarrowPeak file name (fixed width peaks)",
                    "id": "#spp.cwl/savn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savp=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\"; return null}"
                    },
                    "doc": "save cross-correlation plot",
                    "id": "#spp.cwl/savp"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savr=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\"; return null}"
                    },
                    "doc": "-savr=<regionpeakfilename> OR -savr RegionPeak file name (variable width peaks with regions of enrichment)",
                    "id": "#spp.cwl/savr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-speak=",
                        "separate": false
                    },
                    "doc": "-speak=<strPeak>, user-defined cross-correlation peak strandshift",
                    "id": "#spp.cwl/speak"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-x=",
                        "separate": false
                    },
                    "doc": "-x=<min>:<max>, strand shifts to exclude (This is mainly to avoid region around phantom peak) default=10:(readlen+10)",
                    "id": "#spp.cwl/x"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                    },
                    "doc": "peakshift/phantomPeak results summary file",
                    "id": "#spp.cwl/output_spp_cross_corr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\")"
                    },
                    "doc": "peakshift/phantomPeak results summary plot",
                    "id": "#spp.cwl/output_spp_cross_corr_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\")"
                    },
                    "doc": "narrowPeak output file",
                    "id": "#spp.cwl/output_spp_narrow_peak"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\")"
                    },
                    "doc": "Rdata file from the run_spp.R run",
                    "id": "#spp.cwl/output_spp_rdata"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\")"
                    },
                    "doc": "regionPeak output file",
                    "id": "#spp.cwl/output_spp_region_peak"
                }
            ],
            "baseCommand": "run_spp.R",
            "arguments": [
                {
                    "valueFrom": "$(\"-out=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                },
                {
                    "valueFrom": "$(\"-tmpdir=\"+runtime.tmpdir)",
                    "shellQuote": false
                }
            ],
            "id": "#spp.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\nThere are two major modes of the program: Paired end mode and Single end mode. The\npaired end mode will maintain correspondence of read pairs and also use the additional\ninformation contained in paired reads to better find adapter or PCR primer fragments\nintroduced by the library preparation process.\nTrimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores,\ndepending on the Illumina pipeline used).\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/trimmomatic",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "doc": "<quality>\nDrop the read if the average quality is below the specified level\n<quality>: Specifies the minimum average quality required to keep a read.\n",
                    "id": "#trimmomatic.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves bases regardless of quality from the end of the read, so that the read has maximally\nthe specified length after this step has been performed. Steps performed after CROP might of\ncourse further shorten the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "SE|PE\nSingle End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves the specified number of bases, regardless of quality, from the beginning of the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/headcrop"
                },
                {
                    "type": "string",
                    "doc": "<fastaWithAdaptersEtc>:<seed mismatches>:<palindrome clip threshold>:<simple clip threshold>:<minAdapterLength>:<keepBothReads>\nFind and remove Illumina adapters.\nREQUIRED:\n<fastaWithAdaptersEtc>: specifies the path to a fasta file containing all the adapters, PCR sequences etc.\nThe naming of the various sequences within this file determines how they are used. See below.\n<seedMismatches>: specifies the maximum mismatch count which will still allow a full match to be performed\n<palindromeClipThreshold>: specifies how accurate the match between the two 'adapter ligated' reads must be\nfor PE palindrome read alignment.\n<simpleClipThreshold>: specifies how accurate the match between any adapter etc. sequence must be against a read\nOPTIONAL:\n<minAdapterLength>: In addition to the alignment score, palindrome mode can verify\nthat a minimum length of adapter has been detected. If unspecified, this defaults to 8 bases,\nfor historical reasons. However, since palindrome mode has a very low false positive rate, this\ncan be safely reduced, even down to 1, to allow shorter adapter fragments to be removed.\n<keepBothReads>: After read-though has been detected by palindrome mode, and the\nadapter sequence removed, the reverse read contains the same sequence information as the\nforward read, albeit in reverse complement. For this reason, the default behaviour is to\nentirely drop the reverse read. By specifying \"true\" for this parameter, the reverse read will\nalso be retained, which may be useful e.g. if the downstream tools cannot handle a\ncombination of paired and unpaired reads.\n",
                    "id": "#trimmomatic.cwl/illuminaclip"
                },
                {
                    "type": "File",
                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search for and remove these sequences in the input FASTQ file(s)",
                    "id": "#trimmomatic.cwl/input_adapters_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FASTQ file for input read (read R1 in Paired End mode)",
                    "id": "#trimmomatic.cwl/input_read1_fastq_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FASTQ file for read R2 in Paired End mode",
                    "id": "#trimmomatic.cwl/input_read2_fastq_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the beginning. As long as a base has a value below this\nthreshold the base is removed and the next base will be investigated.\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-trimlog"
                    },
                    "doc": "<ouptut log file name>\nSpecifying a trimlog file creates a log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n<ouptut log file name>: filename for the generated output log file.\n",
                    "id": "#trimmomatic.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "MAXINFO:",
                        "separate": false
                    },
                    "doc": "<targetLength>:<strictness>\nPerforms an adaptive quality trim, balancing the benefits of retaining longer reads against the\ncosts of retaining bases with errors.\n<targetLength>: This specifies the read length which is likely to allow the\nlocation of the read within the target sequence to be determined.\n<strictness>: This value, which should be set between 0 and 1, specifies the\nbalance between preserving as much read length as possible vs. removal of incorrect\nbases. A low value of this parameter (<0.2) favours longer reads, while a high value\n(>0.8) favours read correctness.\n",
                    "id": "#trimmomatic.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "<length>\nThis module removes reads that fall below the specified minimal length. If required, it should\nnormally be after all other processing steps. Reads removed by this step will be counted and\nincluded in the \"dropped reads\" count presented in the trimmomatic summary.\n<length>:  Specifies the minimum length of reads to be kept\n",
                    "id": "#trimmomatic.cwl/minlen"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-threads"
                    },
                    "doc": "Number of threads",
                    "id": "#trimmomatic.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": "64",
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "doc": "\"33\"|\"64\"\n-phred33 (\"33\") or -phred64 (\"64\") specifies the base quality encoding. Default: -phred64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "SLIDINGWINDOW:",
                        "separate": false
                    },
                    "doc": "<windowSize>:<requiredQuality>\nPerform a sliding window trimming, cutting once the average quality within the window falls\nbelow a threshold. By considering multiple bases, a single poor quality base will not cause the\nremoval of high quality data later in the read.\n<windowSize>: specifies the number of bases to average across\n<requiredQuality>: specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.",
                    "id": "#trimmomatic.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.",
                    "id": "#trimmomatic.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the end. As long as a base has a value below this threshold\nthe base is removed and the next base (which as trimmomatic is starting from the 3\" prime end\nwould be base preceding the just removed base) will be investigated. This approach can be\nused removing the special illumina \"low quality segment\" regions (which are marked with\nquality score of 2), but we recommend Sliding Window or MaxInfo instead\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/trailing"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-jar"
                    },
                    "id": "#trimmomatic.cwl/trimmomatic_jar_path"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.log_filename)"
                    },
                    "doc": "Trimmomatic Log file.",
                    "id": "#trimmomatic.cwl/output_log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_read1_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.trimmed.fastq.gz'))"
                    },
                    "id": "#trimmomatic.cwl/output_read1_trimmed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.end_mode == \"PE\")\n    return inputs.input_read1_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.unpaired.trimmed.fastq.gz');\n  return null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/output_read1_trimmed_unpaired_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.end_mode == \"PE\" && inputs.input_read2_fastq_file)\n    return inputs.input_read2_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.trimmed.fastq.gz');\n  return null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/output_read2_trimmed_paired_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.end_mode == \"PE\" && inputs.input_read2_fastq_file)\n    return inputs.input_read2_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.unpaired.trimmed.fastq.gz');\n  return null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/output_read2_trimmed_unpaired_file"
                }
            ],
            "baseCommand": "java",
            "arguments": [
                {
                    "valueFrom": "$(\"-Djava.io.tmpdir=\"+runtime.tmpdir)",
                    "shellQuote": false,
                    "position": 1
                },
                {
                    "valueFrom": "$(inputs.input_read1_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.trimmed.fastq.gz'))",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.input_read2_fastq_file)\n    return inputs.input_read1_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.trimmed.unpaired.fastq.gz';\n  return null;\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.input_read2_fastq_file)\n    return inputs.input_read2_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.trimmed.fastq.gz');\n  return null;\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.input_read2_fastq_file)\n    return inputs.input_read2_fastq_file.path.replace(/^.*[\\\\\\/]/, '').replace(/(\\.fq.gz|\\.fastq.gz|\\.[^/.]+)$/, '.unpaired.trimmed.fastq.gz');\n  return null;\n}\n",
                    "position": 10
                },
                {
                    "valueFrom": "$(\"ILLUMINACLIP:\" + inputs.input_adapters_file.path + \":\"+ inputs.illuminaclip)",
                    "position": 11
                }
            ],
            "id": "#trimmomatic.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#basename.cwl/do_not_escape_sep"
                },
                {
                    "type": "string",
                    "id": "#basename.cwl/file_path"
                },
                {
                    "type": "int",
                    "default": 1,
                    "doc": "Number of file extensions to remove",
                    "id": "#basename.cwl/num_ext"
                },
                {
                    "type": "string",
                    "doc": "File extension delimiter",
                    "id": "#basename.cwl/sep"
                }
            ],
            "expression": "${\n  var sep_escaped = !inputs.do_not_escape_sep ? inputs.sep.replace(/[^\\w\\s]/g, \"\\\\$&\") : inputs.sep;\n  var out=inputs.file_path.replace(/^.*[\\\\\\/]/, '');\n  for (var e=0;e<inputs.num_ext; e++){\n    out=out.split(RegExp(\"\\\\b\" + sep_escaped + \"\\\\b\"))[0];\n  }\n  return {\"basename\": out};\n}\n",
            "outputs": [
                {
                    "type": "string",
                    "id": "#basename.cwl/basename"
                }
            ],
            "id": "#basename.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts reads in a fastq file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastq-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastq-reads.cwl/input_fastq_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.read_count.txt')"
                    },
                    "id": "#count-fastq-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": "count-fastq-reads.sh",
            "stdout": "$(inputs.input_basename + '.read_count.txt')",
            "id": "#count-fastq-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts lines in a file and returns a suffixed file with that number",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#count-with-output-suffix.cwl/input_file"
                },
                {
                    "type": "string",
                    "default": ".count",
                    "id": "#count-with-output-suffix.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)"
                    },
                    "id": "#count-with-output-suffix.cwl/output_counts"
                }
            ],
            "baseCommand": [
                "wc",
                "-l"
            ],
            "stdin": "$(inputs.input_file.path)",
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)",
            "id": "#count-with-output-suffix.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts the base name of a file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-basename.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "$(inputs.input_file.path.substr(inputs.input_file.path.lastIndexOf('/') + 1, inputs.input_file.path.lastIndexOf('.') - (inputs.input_file.path.lastIndexOf('/') + 1)))"
                    },
                    "id": "#extract-basename.cwl/output_basename"
                }
            ],
            "baseCommand": "echo",
            "id": "#extract-basename.cwl"
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "doc": "Query chromosome used to calculate percentage",
                    "id": "#idxstats-percentage-of-reads-in-chrom.cwl/chrom"
                },
                {
                    "type": "File",
                    "doc": "Samtools idxstats file",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#idxstats-percentage-of-reads-in-chrom.cwl/idxstats"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Save the percentage in a file of the given name",
                    "id": "#idxstats-percentage-of-reads-in-chrom.cwl/output_filename"
                }
            ],
            "expression": "${\n  var regExp = new RegExp(inputs.chrom + \"\\\\s\\\\d+\\\\s(\\\\d+)\\\\s(\\\\d+)\");\n  var match = inputs.idxstats.contents.match(regExp);\n  var output = inputs.chrom + \" not found\"\n  if (match){\n    var chrom_mapped_reads = match[1];\n    var total_reads = inputs.idxstats.contents.split(\"\\n\")\n      .map(function(x){\n        var rr = x.match(/.*\\s\\d+\\s(\\d+)\\s\\d+/);\n        return (rr ? rr[1] : 0);\n      })\n      .reduce(function(a, b) { return Number(a) + Number(b); });\n    output = (100*chrom_mapped_reads/total_reads).toFixed(4) + \"%\" + \"\\n\";\n  }\n  if (inputs.output_filename){\n    return {\n      percent_map : {\n        \"class\": \"File\",\n        \"basename\" : inputs.output_filename,\n        \"contents\" : output,\n      }\n    }\n  }\n  return output;\n}\n",
            "outputs": [
                {
                    "type": [
                        "File",
                        "string"
                    ],
                    "id": "#idxstats-percentage-of-reads-in-chrom.cwl/percent_map"
                }
            ],
            "id": "#idxstats-percentage-of-reads-in-chrom.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Trunk scores in ENCODE bed6+4 files",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10000
                    },
                    "id": "#trunk-peak-score.cwl/peaks"
                },
                {
                    "type": "string",
                    "default": "\\t",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-F"
                    },
                    "id": "#trunk-peak-score.cwl/sep"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.peaks.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.([^/.]+)$/, \"\\.trunked_scores\\.$1\"))"
                    },
                    "id": "#trunk-peak-score.cwl/trunked_scores_peaks"
                }
            ],
            "baseCommand": "awk",
            "arguments": [
                {
                    "valueFrom": "BEGIN{OFS=FS}$5>1000{$5=1000}{print}",
                    "position": 3
                }
            ],
            "stdout": "$(inputs.peaks.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.([^/.]+)$/, \"\\.trunked_scores\\.$1\"))",
            "id": "#trunk-peak-score.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
